<?php
/**
 * @author  RadiusTheme
 * @since   1.0
 * @version 1.0
 */
namespace radiustheme\aeen\Customizer\Settings;

use radiustheme\aeen\Customizer\RDTheme_Customizer;
use radiustheme\aeen\Customizer\Controls\Customizer_Heading_Control;
use radiustheme\aeen\Customizer\Controls\Customizer_Switch_Control;
use radiustheme\aeen\Customizer\Controls\Customizer_Separator_Control;

use WP_Customize_Media_Control;
use WP_Customize_Color_Control;

/**
 * Adds the individual sections, settings, and controls to the theme customizer
 */
class RDTheme_Colors_Settings extends RDTheme_Customizer {

	public function __construct() {
	    parent::instance();
        $this->populated_default_data();
        // Add Controls
        add_action( 'customize_register', array( $this, 'register_colors_controls' ) );
	}

    public function register_colors_controls( $wp_customize ) {

        /**
         * Heading
         */
        $wp_customize->add_setting('theme_colors', array(
            'default' => '',
            'sanitize_callback' => 'esc_html',
        ));
        $wp_customize->add_control(new Customizer_Heading_Control($wp_customize, 'theme_colors', array(
            'label' => __( 'Theme Colors', 'aeen' ),
            'section' => 'color_section',
        )));

        /*Global Color*/
        $wp_customize->add_setting('primary_color', 
            array(
                'default' => $this->defaults['primary_color'],
                'type' => 'theme_mod', 
                'capability' => 'edit_theme_options', 
                'transport' => 'refresh', 
                'sanitize_callback' => 'sanitize_hex_color',
            )
        );
        $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'primary_color',
            array(
                'label' => esc_html__('Primary Color', 'aeen'),
                'section' => 'color_section', 
            )
        ));
        
        $wp_customize->add_setting('secondary_color', 
            array(
                'default' => $this->defaults['secondary_color'],
                'type' => 'theme_mod', 
                'capability' => 'edit_theme_options', 
                'transport' => 'refresh', 
                'sanitize_callback' => 'sanitize_hex_color',
            )
        );
        $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'secondary_color',
            array(
                'label' => esc_html__('Secondary Color', 'aeen'),
                'section' => 'color_section', 
            )
        ));     
                
        $wp_customize->add_setting('body_color', 
            array(
                'default' => $this->defaults['body_color'],
                'type' => 'theme_mod', 
                'capability' => 'edit_theme_options', 
                'transport' => 'refresh', 
                'sanitize_callback' => 'sanitize_hex_color',
            )
        );
        $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'body_color',
            array(
                'label' => esc_html__('Body Color', 'aeen'),
                'section' => 'color_section', 
            )
        ));


        /**
         * Menu Style
         */
        $wp_customize->add_setting('theme_menu_style', array(
            'default' => '',
            'sanitize_callback' => 'esc_html',
        ));
        $wp_customize->add_control(new Customizer_Heading_Control($wp_customize, 'theme_menu_style', array(
            'label' => __( 'Menu Style', 'aeen' ),
            'section' => 'color_section',
        )));


        // Switch for Menu Style
        $wp_customize->add_setting( 'main_menu_style',
            array(
                'default'           => $this->defaults['main_menu_style'],
                'transport'         => 'refresh',
                'sanitize_callback' => 'rttheme_switch_sanitization',
            )
        );
        $wp_customize->add_control( new Customizer_Switch_Control( $wp_customize, 'main_menu_style',
            array(
                'label'   => __( 'Menu Style', 'aeen' ),
                'section' => 'color_section',
            )
        ) );

         // Main Menu Font color
        $wp_customize->add_setting('main_menu_font_color', 
            array(
                'default' => $this->defaults['main_menu_font_color'], 
                'type' => 'theme_mod', 
                'capability' => 'edit_theme_options', 
                'transport' => 'refresh', 
                'sanitize_callback' => 'sanitize_hex_color',
                'active_callback' => 'rttheme_is_main_menu_style_enabled',
            )
        );
        $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'main_menu_font_color',
            array(
                'label' => esc_html__('Main Menu Font Color', 'aeen'),
                'settings' => 'main_menu_font_color', 
                'priority' => 10, 
                'section' => 'color_section', 
                'active_callback' => 'rttheme_is_main_menu_style_enabled',
            )
        ));

         // Main Menu Font hover color
        $wp_customize->add_setting('main_menu_font_hover_color', 
            array(
                'default' => $this->defaults['main_menu_font_hover_color'], 
                'type' => 'theme_mod', 
                'capability' => 'edit_theme_options', 
                'transport' => 'refresh', 
                'sanitize_callback' => 'sanitize_hex_color',
                'active_callback' => 'rttheme_is_main_menu_style_enabled',
            )
        );
        $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'main_menu_font_hover_color',
            array(
                'label' => esc_html__('Main Menu Font Hover Color', 'aeen'),
                'settings' => 'main_menu_font_hover_color', 
                'priority' => 10, 
                'section' => 'color_section', 
                'active_callback' => 'rttheme_is_main_menu_style_enabled',
            )
        ));


         // Sub Menu Font color
        $wp_customize->add_setting('sub_menu_font_color', 
            array(
                'default' => $this->defaults['sub_menu_font_color'], 
                'type' => 'theme_mod', 
                'capability' => 'edit_theme_options', 
                'transport' => 'refresh', 
                'sanitize_callback' => 'sanitize_hex_color',
                'active_callback' => 'rttheme_is_main_menu_style_enabled',
            )
        );
        $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'sub_menu_font_color',
            array(
                'label' => esc_html__('Sub Menu Font Color', 'aeen'),
                'settings' => 'sub_menu_font_color', 
                'priority' => 10, 
                'section' => 'color_section', 
                'active_callback' => 'rttheme_is_main_menu_style_enabled',
            )
        ));

         // Sub Menu Font hover color
        $wp_customize->add_setting('sub_menu_font_hover_color', 
            array(
                'default' => $this->defaults['sub_menu_font_hover_color'], 
                'type' => 'theme_mod', 
                'capability' => 'edit_theme_options', 
                'transport' => 'refresh', 
                'sanitize_callback' => 'sanitize_hex_color',
                'active_callback' => 'rttheme_is_main_menu_style_enabled',
            )
        );
        $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'sub_menu_font_hover_color',
            array(
                'label' => esc_html__('Sub Menu Font Hover Color', 'aeen'),
                'settings' => 'sub_menu_font_hover_color', 
                'priority' => 10, 
                'section' => 'color_section', 
                'active_callback' => 'rttheme_is_main_menu_style_enabled',
            )
        ));


         // Sub Menu Background hover color
        $wp_customize->add_setting('sub_menu_bg_hover_color', 
            array(
                'default' => $this->defaults['sub_menu_bg_hover_color'], 
                'type' => 'theme_mod', 
                'capability' => 'edit_theme_options', 
                'transport' => 'refresh', 
                'sanitize_callback' => 'sanitize_hex_color',
                'active_callback' => 'rttheme_is_main_menu_style_enabled',
            )
        );
        $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'sub_menu_bg_hover_color',
            array(
                'label' => esc_html__('Sub Menu Background Hover Color', 'aeen'),
                'settings' => 'sub_menu_bg_hover_color', 
                'priority' => 10, 
                'section' => 'color_section', 
                'active_callback' => 'rttheme_is_main_menu_style_enabled',
            )
        ));
        

    }

}

/**
 * Initialise our Customizer settings only when they're required
 */
if ( class_exists( 'WP_Customize_Control' ) ) {
	new RDTheme_Colors_Settings();
}
