<?php
/**
 * @author  RadiusTheme
 * @since   1.0
 * @version 1.0
 */

namespace radiustheme\aeen;
use radiustheme\aeen\inc\RDTheme;
use radiustheme\aeen\inc\Helper;

class Layouts {
	public $aeen = AEEN_THEME_PREFIX;
	public $cpt  = AEEN_THEME_CPT_PREFIX;

	public function __construct() {
		add_action( 'template_redirect', array( $this, 'layout_settings' ) );
	}
	public function layout_settings() {
		// Single Pages
		if( is_single() || is_page() ) {
			$post_type = get_post_type();
			$post_id   = get_the_ID();

			switch( $post_type ) {
				case 'page':
					$aeen = 'page';
					break;
				case 'post':
					$aeen = 'single_post';
					break;
				default:
					$aeen = 'single_post';
					break;
			}

			$layout         	  = get_post_meta( $post_id, "{$this->cpt}_layout", true );
			$top_bar              = get_post_meta( $post_id, "{$this->cpt}_top_bar", true );
			$header_style   	  = get_post_meta( $post_id, "{$this->cpt}_header", true );
			$transparent_header   = get_post_meta( $post_id, "{$this->cpt}_transparent_header", true );

			$footer_style   	  = get_post_meta( $post_id, "{$this->cpt}_footer", true );
			$has_banner     	  = get_post_meta( $post_id, "{$this->cpt}_banner", true );
			$has_breadcrumb 	  = get_post_meta( $post_id, "{$this->cpt}_breadcrumb", true );
			$bgtype         	  = get_post_meta( $post_id, "{$this->cpt}_banner_type", true );
			$bgcolor        	  = get_post_meta( $post_id, "{$this->cpt}_banner_bgcolor", true );
			$bgimg          	  = get_post_meta( $post_id, "{$this->cpt}_banner_bgimg", true );			
			$bgimgoverlay   	  = get_post_meta( $post_id, "{$this->cpt}_banner_bgimage_overlay", true );	
			$overlayopacity 	  = get_post_meta( $post_id, "{$this->cpt}_overlay_opacity", true );
			$inner_padding_top    = get_post_meta( $post_id, "{$this->cpt}_inner_padding_top", true );	
			$inner_padding_bottom = get_post_meta( $post_id, "{$this->cpt}_inner_padding_bottom", true );

			
			RDTheme::$layout = ( empty( $layout ) || $layout == 'default' ) ? RDTheme::$options[$aeen . '_layout'] : $layout;

			RDTheme::$header_style = ( empty( $header_style ) || $header_style == 'default' ) ? RDTheme::$options['header_style'] : $header_style;
			RDTheme::$top_bar_style = ( empty( $top_bar_style ) || $top_bar_style == 'default' ) ? RDTheme::$options['top_bar_style'] : $top_bar_style;

			RDTheme::$transparent_header = ( empty( $transparent_header ) || $transparent_header == 'default' ) ? RDTheme::$options['transparent_header'] : $transparent_header;
			RDTheme::$top_bar = ( empty( $top_bar ) || $top_bar == 'default' ) ? RDTheme::$options['top_bar'] : $top_bar;	

			RDTheme::$footer_style = ( empty( $footer_style ) || $footer_style == 'default' ) ? RDTheme::$options['footer_style'] : $footer_style;

			RDTheme::$has_banner = ( empty( $has_banner ) || $has_banner == 'default' ) ? RDTheme::$options[$aeen . '_banner'] : $has_banner;

			RDTheme::$has_breadcrumb = ( empty( $has_breadcrumb ) || $has_breadcrumb == 'default' ) ? RDTheme::$options[$aeen . '_breadcrumb'] : $has_breadcrumb;

			RDTheme::$bgtype = ( empty( $bgtype ) || $bgtype == 'default' ) ? RDTheme::$options[$aeen . '_banner_bg_type'] : $bgtype;

			RDTheme::$bgcolor = empty( $bgcolor ) ? RDTheme::$options[$aeen . '_banner_bgcolor'] : $bgcolor;

			RDTheme::$inner_padding_top = empty( $inner_padding_top ) ? RDTheme::$options[$aeen . '_inner_padding_top'] : $inner_padding_top;

			RDTheme::$inner_padding_bottom = empty( $inner_padding_bottom ) ? RDTheme::$options[$aeen . '_inner_padding_bottom'] : $inner_padding_bottom;


			if( !empty( $bgimg ) ) {
				$attch_url      = wp_get_attachment_image_src( $bgimg, 'full', true );
				RDTheme::$bgimg = $attch_url[0];
			}
			elseif( !empty( RDTheme::$options[$aeen . '_banner_bgimg']) ) {
				$attch_url      = wp_get_attachment_image_src( RDTheme::$options[$aeen . '_banner_bgimg'], 'full', true );
				RDTheme::$bgimg = $attch_url[0];
			}
			else {
				RDTheme::$bgimg = Helper::get_img( 'banner.jpg' );
			}
			if ( !is_active_sidebar( 'sidebar' ) ){
				RDTheme::$layout = 'full-width';
			}

			RDTheme::$bgimgoverlay = empty( $bgimgoverlay ) ? RDTheme::$options[$aeen . '_banner_bgimage_overlay'] : $bgimgoverlay;

			RDTheme::$overlayopacity = empty( $overlayopacity ) ? RDTheme::$options[$aeen . '_overlay_opacity'] : $overlayopacity;

		}

		// Blog and Archive
		elseif( is_home() || is_archive() || is_search() || is_404() ) {
			$aeen = 'page';

			RDTheme::$layout               = RDTheme::$options['blog_layout'];
			RDTheme::$top_bar        	   = RDTheme::$options['top_bar'];
			RDTheme::$top_bar_style        = RDTheme::$options['top_bar_style'];
			RDTheme::$header_style         = RDTheme::$options['header_style'];
			RDTheme::$transparent_header   = RDTheme::$options['transparent_header'];
			RDTheme::$footer_style         = RDTheme::$options['footer_style'];
			RDTheme::$has_banner           = RDTheme::$options[$aeen . '_banner'];
			RDTheme::$has_breadcrumb       = RDTheme::$options[$aeen . '_breadcrumb'];
			RDTheme::$bgtype               = RDTheme::$options[$aeen . '_banner_bg_type'];
			RDTheme::$bgcolor              = RDTheme::$options[$aeen . '_banner_bgcolor'];
			RDTheme::$bgimgoverlay         = RDTheme::$options[$aeen . '_banner_bgimage_overlay'];
			RDTheme::$overlayopacity       = RDTheme::$options[$aeen . '_overlay_opacity'];
			RDTheme::$inner_padding_top    = RDTheme::$options[$aeen . '_inner_padding_top'];
			RDTheme::$inner_padding_bottom = RDTheme::$options[$aeen . '_inner_padding_bottom'];

			if( is_search() ) {
				$aeen = 'search';
			}
			elseif( is_404() ) {
				$aeen = 'error';
			}
			elseif( is_post_type_archive( "{$this->cpt}_team" ) || is_tax( "{$this->cpt}_team_category" ) ) {
				$aeen = 'team_archive';
			}elseif ( is_post_type_archive( "{$this->cpt}_case_study" ) || is_tax( "{$this->cpt}_case_study_category" ) ) {
				$aeen = 'casestudy_archive';
			}elseif ( is_post_type_archive( "{$this->cpt}_practice" ) || is_tax( "{$this->cpt}_practice_category" ) ) {
				$aeen = 'practice_archive';
			}				
			else {
				$aeen = 'blog';
			}
		

			if( !empty( RDTheme::$options[$aeen . '_banner_bgimg']) ) {
				$attch_url      = wp_get_attachment_image_src( RDTheme::$options[$aeen . '_banner_bgimg'], 'full', true );
				RDTheme::$bgimg = $attch_url[0];
			} else {
				RDTheme::$bgimg = Helper::get_img( 'banner.jpg' );
			}
			if ( !is_active_sidebar( 'sidebar' ) ){
				RDTheme::$layout = 'full-width';
			}
		}

		if ( is_singular( 'aeen_team' ) ) {
			if ( !empty( RDTheme::$options['steam_page_banner_bgimg'] ) ) {
				$attch_url      = wp_get_attachment_image_src( RDTheme::$options['steam_page_banner_bgimg'], 'full', true );
				RDTheme::$bgimg = $attch_url[0];
			}
			
			RDTheme::$has_banner           = RDTheme::$options['steam_page_banner'];
			RDTheme::$has_breadcrumb       = RDTheme::$options['steam_page_breadcrumb'];
			RDTheme::$bgtype               = RDTheme::$options['steam_page_banner_bg_type'];
			RDTheme::$bgimg                = RDTheme::$bgimg;
			RDTheme::$bgcolor              = RDTheme::$options['steam_page_banner_bgcolor'];
			RDTheme::$bgimgoverlay         = RDTheme::$options['steam_page_banner_bgimage_overlay'];
			RDTheme::$overlayopacity       = RDTheme::$options['steam_page_overlay_opacity'];
			RDTheme::$inner_padding_top    = RDTheme::$options['team_sin_inner_padding_top'];
			RDTheme::$inner_padding_bottom = RDTheme::$options['team_sin_inner_padding_bottom'];
		}elseif( is_singular( 'aeen_practice' ) ){
			if ( !empty( RDTheme::$options['spractice_page_banner_bgimg'] ) ) {
				$attch_url      = wp_get_attachment_image_src( RDTheme::$options['spractice_page_banner_bgimg'], 'full', true );
				RDTheme::$bgimg = $attch_url[0];
			}
			
			RDTheme::$has_banner           = RDTheme::$options['spractice_page_banner'];
			RDTheme::$has_breadcrumb       = RDTheme::$options['spractice_page_breadcrumb'];
			RDTheme::$bgtype               = RDTheme::$options['spractice_page_banner_bg_type'];
			RDTheme::$bgimg                = RDTheme::$bgimg;
			RDTheme::$bgcolor              = RDTheme::$options['spractice_page_banner_bgcolor'];
			RDTheme::$bgimgoverlay         = RDTheme::$options['spractice_page_banner_bgimage_overlay'];
			RDTheme::$overlayopacity       = RDTheme::$options['spractice_page_overlay_opacity'];
			RDTheme::$inner_padding_top    = RDTheme::$options['practice_sin_inner_padding_top'];
			RDTheme::$inner_padding_bottom = RDTheme::$options['practice_sin_inner_padding_bottom'];
		}elseif( is_singular( 'aeen_case_study' ) ){
			if ( !empty( RDTheme::$options['scase_page_banner_bgimg'] ) ) {
				$attch_url      = wp_get_attachment_image_src( RDTheme::$options['scase_page_banner_bgimg'], 'full', true );
				RDTheme::$bgimg = $attch_url[0];
			}
			
			RDTheme::$has_banner           = RDTheme::$options['scase_page_banner'];
			RDTheme::$has_breadcrumb       = RDTheme::$options['scase_page_breadcrumb'];
			RDTheme::$bgtype               = RDTheme::$options['scase_page_banner_bg_type'];
			RDTheme::$bgimg                = RDTheme::$bgimg;
			RDTheme::$bgcolor              = RDTheme::$options['scase_page_banner_bgcolor'];
			RDTheme::$bgimgoverlay         = RDTheme::$options['scase_page_banner_bgimage_overlay'];
			RDTheme::$overlayopacity       = RDTheme::$options['scase_page_overlay_opacity'];
			RDTheme::$inner_padding_top    = RDTheme::$options['case_sin_inner_padding_top'];
			RDTheme::$inner_padding_bottom = RDTheme::$options['case_sin_inner_padding_bottom'];
		}else{
			RDTheme::$has_banner           = RDTheme::$has_banner;
			RDTheme::$has_breadcrumb       = RDTheme::$has_breadcrumb;
			RDTheme::$bgtype               = RDTheme::$bgtype;
			RDTheme::$bgcolor              = RDTheme::$bgcolor;
			RDTheme::$bgimgoverlay         = RDTheme::$bgimgoverlay;
			RDTheme::$overlayopacity       = RDTheme::$overlayopacity ;
			RDTheme::$inner_padding_top    = RDTheme::$inner_padding_top;
			RDTheme::$inner_padding_bottom = RDTheme::$inner_padding_bottom;	
		}
	}
}
new Layouts;



