<?php
/**
 * This file can be overridden by copying it to yourtheme/elementor-custom/title/class.php
 * 
 * @author  RadiusTheme
 * @since   1.0
 * @version 1.0
 */

namespace radiustheme\Aeen_Core;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Typography;

if ( ! defined( 'ABSPATH' ) ) exit;

class Rt_Brand_Logos extends Custom_Widget_Base {

	public function __construct( $data = [], $args = null ){
		$this->rt_name = __( 'RT Brand Logos', 'aeen-core' );
		$this->rt_base = 'rt-brand-logos';
		parent::__construct( $data, $args );
	}


	public function rt_load_scripts(){
		wp_enqueue_style(  'owl-carousel' );
		wp_enqueue_style(  'owl-theme' );
		wp_enqueue_script( 'owl-carousel' );
	}

	public function rt_fields(){

		$repeater = new \Elementor\Repeater();

		$repeater->add_control(
			'brand_img', [
				'type'        => Controls_Manager::MEDIA,
				'label'   => esc_html__( 'Image', 'aeen-core' ),
				'default' => [
                    'url' => $this->rt_placeholder_image(),
                ],
				'description' => esc_html__( 'Recommended full image', 'aeen-core' ),
			]
		);

		$repeater->add_control(
			'brand_url', [
				'type'        => Controls_Manager::URL,
				'label'       => esc_html__( 'Link (Optional)', 'aeen-core' ),
				'placeholder' => 'https://your-link.com',
			]
		);

		$fields = array(
			array(
				'mode'    => 'section_start',
				'id'      => 'sec_general',
				'label'   => esc_html__( 'General', 'aeen-core' ),
			),
			array(
				'type'    => Controls_Manager::SELECT2,
				'id'      => 'style',
				'label'   => esc_html__( 'Style', 'aeen-core' ),
				'options' => array(
					'style1' => esc_html__( 'Style 1', 'aeen-core' ),
					'style2' => esc_html__( 'Style 2', 'aeen-core' ),
					'style3' => esc_html__( 'Style 3', 'aeen-core' ),
				),
				'default' => 'style1',
			),
			array(
				'id'      => 'brand_logos',
				'type'    => Controls_Manager::GALLERY,
				'label'   => __( 'Logo Image', 'aeen-core' ),
				'condition' => array( 'style' => array( 'style1', 'style2' ) ),
			),

			array(
				'id'      => 'title',
				'type'    => Controls_Manager::TEXT,
				'label'   => __( 'Title', 'aeen-core' ),
				'default' => esc_html__( 'Our Partners', 'aeen-core' ),
				'condition' => array( 'style' => array( 'style3' ) ),
			),

			array (
				'type'    => Controls_Manager::REPEATER,
				'id'      => 'brand_lists',
				'label'   => esc_html__( 'Brands', 'aeen-core' ),
				'fields' => $repeater->get_controls(),
				'default' => [
					['brand_img' => '' ],	         
					['brand_img' => '' ],	         
					['brand_img' => '' ],	         
					['brand_img' => '' ],	         
					['brand_img' => '' ],	         
					['brand_img' => '' ],	         
					['brand_img' => '' ],	         
					['brand_img' => '' ],	         
		       ],
		       'condition' => array( 'style' => array( 'style3' ) ),
			),

			array(
				'mode' => 'section_end',
			),
			
			// Style
			array(
				'id'      => 'title_style',
				'mode'    => 'section_start',
				'tab'     => Controls_Manager::TAB_STYLE,
				'label'   => __( 'Title Style', 'aeen-core' ),
				'condition' => array( 'style' => array( 'style3' ) ),
			),
			array(
				'id'      => 'title_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Color', 'aeen-core' ),
				'selectors' => array( 
					'{{WRAPPER}} .brand-area .heading-main-title' => 'color: {{VALUE}}',  
				),
			),
			array(
				'mode'     => 'group',
				'type'     => Group_Control_Typography::get_type(),
				'name'     => 'title_typo',
				'label'    => __( 'Typography', 'aeen-core' ),
				'selector' => '{{WRAPPER}} .brand-area .heading-main-title',
			),
			array(
	            'type'    => Controls_Manager::DIMENSIONS,
	            'size_units' => [ 'px', '%', 'em' ],
	            'id'      => 'title_padding',
	             'mode'          => 'responsive',
	            'label'   => esc_html__( 'Padding', 'salion-core' ),
	            'selectors' => array(
	                '{{WRAPPER}} .brand-area .heading-main-title' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',                  
	            ),
	            'separator' => 'before',
	        ),  
	        array(
	            'type'    => Controls_Manager::DIMENSIONS,
	            'size_units' => [ 'px', '%', 'em' ],
	             'mode'          => 'responsive',
	            'id'      => 'title_margin',
	            'label'   => esc_html__( 'Margin', 'salion-core' ),                 
	            'selectors' => array(
	                '{{WRAPPER}} .brand-area .heading-main-title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',                   
	            ),
	            'separator' => 'before',
	        ),
			array(
				'mode' => 'section_end',
			),
			array(
				'id'      => 'gallery_style',
				'mode'    => 'section_start',
				'tab'     => Controls_Manager::TAB_STYLE,
				'label'   => __( 'Style', 'aeen-core' ),
				'condition' => array( 'style' => array( 'style1', 'style2' ) ),
			),
			array(
				'name'       => 'bg_color',
				'mode'     => 'group',
				'type'     => Group_Control_Background::get_type(),
				'label'    => __( 'Background', 'aeen-core' ),
				'selector' => '{{WRAPPER}} .brand-grid .brand-box',
			),
			array(
				'id'      => 'hover_heading',
				'type' => Controls_Manager::HEADING,
				'label'   => __( 'Border Background Color', 'aeen-core' ),
				'separator' => 'before',
			),
			array(
				'name'       => 'border_color',
				'mode'     => 'group',
				'type'     => Group_Control_Background::get_type(),
				'label'    => __( 'Background', 'aeen-core' ),
				'selector' => '{{WRAPPER}} .brand-grid .brand-box.brand-border:after',
			),
			array(
				'mode' => 'section_end',
			),
		);
		return $fields;
	}

	protected function render() {
		$data = $this->get_settings();

		$this->rt_load_scripts();

		switch ($data['style']) {
			case 'style3':
			$template = 'view-3';
			break;
			case 'style2':
			$template = 'view-2';
			break;
			default:
			$template = 'view-1';
			break;
		}
		
		return $this->rt_template( $template, $data );
	}
}