<?php
/**
 * This file can be overridden by copying it to yourtheme/elementor-custom/title/class.php
 * 
 * @author  RadiusTheme
 * @since   1.0
 * @version 1.0
 */

namespace radiustheme\Aeen_Core;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Background;

if ( ! defined( 'ABSPATH' ) ) exit;

class Career_Info extends Custom_Widget_Base {

	public function __construct( $data = [], $args = null ){
		$this->rt_name = __( 'RT Career Info', 'aeen-core' );
		$this->rt_base = 'rt-career-info';
		parent::__construct( $data, $args );
	}

	public function rt_fields(){
		$fields = array(
			array(
				'id'      => 'sec_general',
				'mode'    => 'section_start',
				'label'   => __( 'General', 'aeen-core' ),
			),
			array(
				'type'    => Controls_Manager::SELECT2,
				'id'      => 'style',
				'label'   => esc_html__( 'Style', 'aeen-core' ),
				'options' => array(
					'style1' => esc_html__( 'Style 1', 'aeen-core' ),
					'style2' => esc_html__( 'Style 2', 'aeen-core' ),
				),
				'default' => 'style1',
			),

			// Career Info Box 1 Repeater
			array(
				'type'    => Controls_Manager::REPEATER,
				'id'      => 'career_box1',
				'label'   => esc_html__( 'Add as many boxes as you want', 'aeen-core' ),
				'fields'  => array(
					array(
						'type'    => Controls_Manager::TEXT,
						'name'    => 'cbox1_title',
						'label'   => esc_html__( 'Title', 'aeen-core' ),
						'default' => esc_html__( 'Department:', 'aeen-core' ),
					),
					array(
						'type'    => Controls_Manager::TEXTAREA,
						'name'    => 'cbox1_content',
						'label'   => esc_html__( 'Content', 'aeen-core' ),
						'default' => esc_html__( 'Insurance Department', 'aeen-core' ),
					),
				),
				'default' => array(
					array( 'cbox1_title' => 'Department:', 'cbox1_content' => 'Insurance Department' ),
					array( 'cbox1_title' => 'Location:', 'cbox1_content' => 'Street Boston, United States' ),
					array( 'cbox1_title' => 'Education:', 'cbox1_content' => 'Master’s Degree' ),
					array( 'cbox1_title' => 'Salary:', 'cbox1_content' => '$7000 - $9500' ),
					array( 'cbox1_title' => 'Experience:', 'cbox1_content' => 'More Than 2 Years' ),
					array( 'cbox1_title' => 'Till:', 'cbox1_content' => 'SEP 24, 2019' ),
				),
				'condition' => array( 'style' => array( 'style1' ) ),
			),

			// Career Info Box 2 Repeater
			array(
				'type'        => Controls_Manager::TEXT,
				'id'          => 'cbox2_title',
				'label'       => esc_html__( 'Title', 'aeen-core' ),
				'default'     => esc_html__( 'What you will do :', 'aeen-core' ),
				'label_block' => true,
				'condition' => array( 'style' => array( 'style2' ) ),
			),
			array(
				'type'        => Controls_Manager::TEXTAREA,
				'id'          => 'cbox2_content',
				'label'       => esc_html__( 'Content', 'aeen-core' ),
				'default'     => esc_html__( 'Grursus mal suada faci lisis Lorem ipsum dolarorit more a ametion consectetur elit. Vesti at bulum nec odio aea the dumm ipsumm ipsum that dolocons rsus mal suada and fadolorit consectetur elit.', 'aeen-core' ),
				'label_block' => true,
				'condition' => array( 'style' => array( 'style2' ) ),
			),

			// Career Info Box 2 Repeater
			array(
				'type'    => Controls_Manager::REPEATER,
				'id'      => 'career_box2',
				'label'   => esc_html__( 'Add as many boxes as you want', 'aeen-core' ),
				'fields'  => array(
					array(
						'type'    => Controls_Manager::TEXT,
						'name'    => 'cbox2_item',
						'label'   => esc_html__( 'Item', 'aeen-core' ),
						'default' => esc_html__( 'A current practicing certificate, or have completed a practical legal training course', 'aeen-core' ),
						'label_block' => true,
					),
				),
				'default' => array(
					array( 
						'cbox2_item' => __( 'A current practicing certificate, or have completed a practical legal training course', 'aeen-core' )
						 ),
					array( 
						'cbox2_item' => __('Excellent analytical, drafting and communication skills', 'aeen-core' ) 
					),
				),
				'condition' => array( 'style' => array( 'style2' ) ),
			),
			array(
				'mode' => 'section_end',
			),

			array(
				'id'      => 'sec_style',
				'mode'    => 'section_start',
				'tab'     => Controls_Manager::TAB_STYLE,
				'label'   => __( 'Style', 'aeen-core' ),
			),
			array(
				'id'      => 'title_heading',
				'type' => Controls_Manager::HEADING,
				'label'   => __( 'Title Style', 'aeen-core' ),
				'separator' => 'before',
			),
			array(
				'id'      => 'title_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Color', 'aeen-core' ),
				'default' => '',
				'selectors' => array( 
					'{{WRAPPER}} .careers-box3 .block-items .single-item .inline-career-info li' => 'color: {{VALUE}}', 
					'{{WRAPPER}} .careers-box3 .block-items .single-item h3' => 'color: {{VALUE}}', 
				),
			),
			array(
				'mode'     => 'group',
				'type'     => Group_Control_Typography::get_type(),
				'name'     => 'title_typo',
				'label'    => __( 'Typography', 'aeen-core' ),
				'selector' => '{{WRAPPER}} .careers-box3 .block-items .single-item .inline-career-info li, {{WRAPPER}} .careers-box3 .block-items .single-item h3',
			),
			array(
				'id'      => 'desc_heading',
				'type' => Controls_Manager::HEADING,
				'label'   => __( 'Description Style', 'aeen-core' ),
				'separator' => 'before',
			),
			array(
				'id'      => 'desc_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Color', 'aeen-core' ),
				'default' => '',
				'selectors' => array( 
					'{{WRAPPER}} .careers-box3 .block-items .single-item .inline-career-info li span' => 'color: {{VALUE}}', 
					'{{WRAPPER}} .careers-box3 .block-items .single-item p' => 'color: {{VALUE}}', 
				),
			),
			array(
				'mode'     => 'group',
				'type'     => Group_Control_Typography::get_type(),
				'name'     => 'desc_typo',
				'label'    => __( 'Typography', 'aeen-core' ),
				'selector' => '{{WRAPPER}} .careers-box3 .block-items .single-item .inline-career-info li span, {{WRAPPER}} .careers-box3 .block-items .single-item p',
			),
			array(
				'mode' => 'section_end',
			),
		);
		return $fields;
	}

	protected function render() {
		$data = $this->get_settings();

		switch ($data['style']) {
			case 'style2':
			$template = 'view-2';
			break;
			default:
			$template = 'view-1';
			break;
		}

		return $this->rt_template( $template, $data );
	}
}