<?php
/**
 * This file can be overridden by copying it to yourtheme/elementor-custom/title/class.php
 * 
 * @author  RadiusTheme
 * @since   1.0
 * @version 1.0
 */

namespace radiustheme\Aeen_Core;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Background;

if ( ! defined( 'ABSPATH' ) ) exit;

class Case_Studies_Isotope extends Custom_Widget_Base {

	public function __construct( $data = [], $args = null ){
		$this->rt_name = __( 'Case Studies Isotope', 'aeen-core' );
		$this->rt_base = 'case-studies-isotope';
		$this->rt_translate = array(
			'cols'  => array(
				'12' => esc_html__( '1 Col', 'aeen-core' ),
				'6'  => esc_html__( '2 Col', 'aeen-core' ),
				'4'  => esc_html__( '3 Col', 'aeen-core' ),
				'3'  => esc_html__( '4 Col', 'aeen-core' ),
				'2'  => esc_html__( '6 Col', 'aeen-core' ),
			),
		);
		parent::__construct( $data, $args );
	}

	public function rt_fields(){

		$cpt = AEEN_CORE_CPT;
		$terms  = get_terms( array( 'taxonomy' => "{$cpt}_case_study_category", 'fields' => 'id=>name' ) );
		$category_dropdown = array( '0' => esc_html__( 'All Categories', 'aeen-core' ) );
		foreach ( $terms as $id => $name ) {
			$category_dropdown[$id] = $name;
		}

		$fields = array(	

			// Layout
			array(
				'mode'    => 'section_start',
				'id'      => 'sec_layout',
				'label'   => esc_html__( 'Layout', 'aeen-core' ),
			),
			array(
				'type'    => Controls_Manager::SELECT2,
				'id'      => 'style',
				'label'   => esc_html__( 'Layout', 'aeen-core' ),
				'options' => array(
					'style1' => esc_html__( 'Style 1', 'aeen-core' ),
					'style2' => esc_html__( 'Style 2', 'aeen-core' ),
					'style3' => esc_html__( 'Style 3', 'aeen-core' ),
					'style4' => esc_html__( 'Style 4', 'aeen-core' ),
				),
				'default' => 'style1',
			),			

			array(
				'type'        => Controls_Manager::SWITCHER,
				'id'          => 'filter',
				'label'       => esc_html__( 'Filter Tabs', 'aeen-core' ),
				'label_on'    => esc_html__( 'On', 'aeen-core' ),
				'label_off'   => esc_html__( 'Off', 'aeen-core' ),
				'default'     => 'yes',
				'description' => esc_html__( 'Filter Tabs. Default: On', 'aeen-core' ),
			),	
			array(
				'type'        => Controls_Manager::SWITCHER,
				'id'          => 'category_display',
				'label'       => esc_html__( 'Category Display', 'aeen-core' ),
				'label_on'    => esc_html__( 'On', 'aeen-core' ),
				'label_off'   => esc_html__( 'Off', 'aeen-core' ),
				'default'     => 'yes',
				'description' => esc_html__( 'Categorys. Default: On', 'aeen-core' ),
				'condition' => array( 'style' => array( 'style1', 'style3', 'style4' )),	
			),
			array(
				'type'        => Controls_Manager::SWITCHER,
				'id'          => 'excerpt_display',
				'label'       => esc_html__( 'Excerpt Display', 'aeen-core' ),
				'label_on'    => esc_html__( 'On', 'aeen-core' ),
				'label_off'   => esc_html__( 'Off', 'aeen-core' ),
				'default'     => 'yes',
				'description' => esc_html__( 'Categorys. Default: On', 'aeen-core' ),
				'condition' => array( 'style' => array( 'style1', 'style3', 'style4' )),	
			),
			array(
		        'type'    => Controls_Manager::SELECT2,
		        'id'      => 'no_of_excerpt_words',
		        'label'   => esc_html__( 'Number Of words for excerpt', 'aeen-core' ),
		        'options' => array(
		          '10' => esc_html__( 10, 'aeen-core' ),
		          '15' => esc_html__( 15, 'aeen-core' ),
		          '16' => esc_html__( 16, 'aeen-core' ),
		          '17' => esc_html__( 17, 'aeen-core' ),
		          '18' => esc_html__( 18, 'aeen-core' ),
		          '19' => esc_html__( 19, 'aeen-core' ),
		          '20' => esc_html__( 20, 'aeen-core' ),
		          '21' => esc_html__( 21, 'aeen-core' ),
		          '22' => esc_html__( 22, 'aeen-core' ),
		          '23' => esc_html__( 23, 'aeen-core' ),
		          '24' => esc_html__( 24, 'aeen-core' ),
		          '25' => esc_html__( 25, 'aeen-core' ),
		          '26' => esc_html__( 26, 'aeen-core' ),
		          '27' => esc_html__( 27, 'aeen-core' ),
		          '28' => esc_html__( 28, 'aeen-core' ),
		          '29' => esc_html__( 29, 'aeen-core' ),
		          '30' => esc_html__( 30, 'aeen-core' ),
		          '35' => esc_html__( 35, 'aeen-core' ),
		          '40' => esc_html__( 40, 'aeen-core' ),
		          '45' => esc_html__( 45, 'aeen-core' ),
		          '50' => esc_html__( 50, 'aeen-core' ),
		          '55' => esc_html__( 55, 'aeen-core' ),
		        ),
		        'default' => 20,
		        'condition' => array( 'excerpt_display' => array( 'yes'),'style' => array( 'style1', 'style2', 'style3', 'style4' ) ),

	      ),
	array(
		'mode' => 'section_end',
	),
	

			// Data Query
			array(
			'mode'    => 'section_start',
			'id'      => 'sec_query',
			'label'   => esc_html__( 'Query', 'aeen-core' ),
			),			
				array(
					'type'    => Controls_Manager::SELECT2,
					'id'      => 'category_list',
					'label'   =>esc_html__( 'Categories', 'aeen-core' ),
					'options' => $category_dropdown,
					'default' => '0',
					'multiple' => true,
				),			
				array(
					'type'    => Controls_Manager::NUMBER,
					'id'      => 'number',
					'label'   =>esc_html__( 'Total number of Projects', 'aeen-core' ),
					'default' => 6,
					'description' =>esc_html__( 'Write -1 to show all', 'aeen-core' ),
				),
				array(
					'type'    => Controls_Manager::SELECT2,
					'id'      => 'orderby',
					'label'   => esc_html__( 'Order By', 'aeen-core' ),
					'options' => array(
						'date'        => esc_html__( 'Date (Recents comes first)', 'aeen-core' ),
						'title'       => esc_html__( 'Title', 'aeen-core' ),
						'menu_order'  => esc_html__( 'Custom Order (Available via Order field inside Page Attributes box)', 'aeen-core' ),
					),
					'default' => 'date',
				),
			array(
			'mode' => 'section_end',
			),


			// Filter Tab Style
			array(
					'mode'    => 'section_start',
					'id'      => 'sec_filter_style',
					'label'   => esc_html__( 'Filter Tab', 'aeen-core' ),
					'tab'     => Controls_Manager::TAB_STYLE,
				),	
			array(
				'type'    => Controls_Manager::COLOR,
				'id'      => 'ftab_color',
				'label'   => esc_html__( 'Color', 'aeen-core' ),
				'default' => '',
				'selectors' => array(
						'{{WRAPPER}} .isotop-btn-layout1 a.nav-item' => 'color: {{VALUE}}',
					),
				),	
			array(
				'type'    => Controls_Manager::COLOR,
				'id'      => 'ftab_active_color',
				'label'   => esc_html__( 'Active Color', 'aeen-core' ),
				'default' => '',
				'selectors' => array(					
						'{{WRAPPER}} .isotop-btn-layout1 a.nav-item.current' => 'color: {{VALUE}}',
					),
				),
			array(
				'type'    => Controls_Manager::COLOR,
				'id'      => 'ftab_hover_color',
				'label'   => esc_html__( 'Hover Color', 'aeen-core' ),
				'default' => '',
				'selectors' => array(					
						'{{WRAPPER}} .isotop-btn-layout1 a.nav-item:hover' => 'color: {{VALUE}}',
					),
				),	  
			array( 
				'mode'      => 'group',
				'type'      => Group_Control_Typography::get_type(),
				'name'      => 'ftab_typo',
				'label'     => esc_html__( 'Typography', 'aeen-core' ),
				'selector'  => '{{WRAPPER}} .isotop-btn-layout1 a.nav-item',
			),

			array(
				'mode' => 'section_end',
			),

			// Title Style
			array(
					'mode'    => 'section_start',
					'id'      => 'sec_title_style',
					'label'   => esc_html__( 'Title', 'aeen-core' ),
					'tab'     => Controls_Manager::TAB_STYLE,
				),
			array(
				'type'        => Controls_Manager::SWITCHER,
				'id'          => 'title_style',
				'label'       =>esc_html__( 'Title Style', 'aeen-core' ),
				'label_on'    =>esc_html__( 'On', 'aeen-core' ),
				'label_off'   =>esc_html__( 'Off', 'aeen-core' ),
				'default'     => 'no',
				'description' =>esc_html__( 'Show or Hide Title Style. Default: Off', 'aeen-core' ),
				),	
			array(
				'type'    => Controls_Manager::COLOR,
				'id'      => 'title_color',
				'label'   => esc_html__( 'Title Color', 'aeen-core' ),
				'default' => '',
				'condition'   => array('title_style' => array( 'yes' ) ),
				'selectors' => array(
						'{{WRAPPER}} .case-study-box-layout3 .item-title a' => 'color: {{VALUE}}',
					),
				),	
			array(
				'type'    => Controls_Manager::COLOR,
				'id'      => 'title_hover_color',
				'label'   => esc_html__( 'Title Hover Color', 'aeen-core' ),
				'default' => '',
				'condition'   => array('title_style' => array( 'yes' ) ),
				'selectors' => array(					
						'{{WRAPPER}} .case-study-box-layout3 .item-title a:hover' => 'color: {{VALUE}}',
					),
				),	  
			array( 
				'mode'      => 'group',
				'type'      => Group_Control_Typography::get_type(),
				'name'      => 'title_typo',
				'label'     => esc_html__( 'Title Typography', 'aeen-core' ),
				'selector'  => '{{WRAPPER}} .case-study-box-layout3 .item-title a',
				'condition'   => array('title_style' => array( 'yes' ) ),
			),

			array(
				'mode' => 'section_end',
			),	

			// Category Style
			array(
				'mode'    => 'section_start',
				'id'      => 'sec_cat_style',
				'label'   => esc_html__( 'Category', 'aeen-core' ),
				'tab'     => Controls_Manager::TAB_STYLE,
				'condition' => array( 'category_display' => array( 'yes') ),
			),
					array(
						'type'        => Controls_Manager::SWITCHER,
						'id'          => 'cat_style',
						'label'       =>esc_html__( 'Categories Style', 'aeen-core' ),
						'label_on'    =>esc_html__( 'On', 'aeen-core' ),
						'label_off'   =>esc_html__( 'Off', 'aeen-core' ),
						'default'     => 'no',
						'description' =>esc_html__( 'Show or Hide Title Style. Default: Off', 'aeen-core' ),
					),	
					array(
						'type'    => Controls_Manager::COLOR,
						'id'      => 'cat_color',
						'label'   => esc_html__( 'Categories Color', 'aeen-core' ),
						'default' => '',
						'condition'   => array('cat_style' => array( 'yes' ) ),
						'selectors' => array(
								'{{WRAPPER}} .case-study-box-layout3 .sub-title a' => 'color: {{VALUE}}',						
							),
					),	
					array(
						'type'    => Controls_Manager::COLOR,
						'id'      => 'cat_hover_color',
						'label'   => esc_html__( 'Categories Hover Color', 'aeen-core' ),
						'default' => '',
						'condition'   => array('cat_style' => array( 'yes' ) ),
						'selectors' => array(					
									'{{WRAPPER}} .case-study-box-layout3 .sub-title a:hover' => 'color: {{VALUE}}',	
							),
					),				 
					array( 
							'mode'      => 'group',
							'type'      => Group_Control_Typography::get_type(),
							'name'      => 'cat_typo',
							'label'     => esc_html__( 'Title Typography', 'aeen-core' ),
							'selector'  => '{{WRAPPER}} .case-study-box-layout3 .sub-title a',
							'condition'   => array('cat_style' => array( 'yes' ) ),
						),
			array(
				'mode' => 'section_end',
			),

			// Content Style
			array(
				'mode'    => 'section_start',
				'id'      => 'sec_content_style',
				'label'   => esc_html__( 'Content', 'aeen-core' ),
				'tab'     => Controls_Manager::TAB_STYLE,
				'condition' => array( 'excerpt_display' => array( 'yes') ),
			),
					array(
						'type'        => Controls_Manager::SWITCHER,
						'id'          => 'content_style',
						'label'       => esc_html__( 'Content Style', 'aeen-core' ),
						'label_on'    => esc_html__( 'On', 'aeen-core' ),
						'label_off'   => esc_html__( 'Off', 'aeen-core' ),
						'default'     => 'no',
						'description' => esc_html__( 'Show or Hide Title Style. Default: Off', 'aeen-core' ),
					),	
					array(
							'type'    => Controls_Manager::COLOR,
							'id'      => 'content_color',
							'label'   => esc_html__( 'Content Color', 'aeen-core' ),
							'default' => '',
							'condition'   => array('content_style' => array( 'yes' ) ),
							'selectors' => array(
									'{{WRAPPER}} .case-study-box-layout3 p' => 'color: {{VALUE}}',							
								),
						),	
					array( 
						'mode'      => 'group',
						'type'      => Group_Control_Typography::get_type(),
						'condition'   => array('content_style' => array( 'yes' ) ),
						'name'      => 'content_typo',
						'label'     => esc_html__( 'Title Typography', 'aeen-core' ),
						'selector'  => '{{WRAPPER}} .case-study-box-layout3 p',
					),
			array(
				'mode' => 'section_end',
			),

			// Responsive Columns
			array(
				'mode'    => 'section_start',
				'id'      => 'sec_responsive',
				'label'   => esc_html__( 'Number of Responsive Columns', 'aeen-core' ),
			),
					array(
						'type'    => Controls_Manager::SELECT2,
						'id'      => 'col_lg',
						'label'   => esc_html__( 'Desktops: > 1199px', 'aeen-core' ),
						'options' => $this->rt_translate['cols'],
						'default' => '4',
					),
					array(
						'type'    => Controls_Manager::SELECT2,
						'id'      => 'col_md',
						'label'   => esc_html__( 'Desktops: > 991px', 'aeen-core' ),
						'options' => $this->rt_translate['cols'],
						'default' => '4',
					),
					array(
						'type'    => Controls_Manager::SELECT2,
						'id'      => 'col_sm',
						'label'   => esc_html__( 'Tablets: > 767px', 'aeen-core' ),
						'options' => $this->rt_translate['cols'],
						'default' => '6',
					),
					array(
						'type'    => Controls_Manager::SELECT2,
						'id'      => 'col_xs',
						'label'   => esc_html__( 'Phones: < 768px', 'aeen-core' ),
						'options' => $this->rt_translate['cols'],
						'default' => '12',
					),
			array(
				'mode' => 'section_end',
			),
		);
		return $fields;
	}

	protected function render() {
		$data = $this->get_settings();

		switch ($data['style']) {
			case 'style4':
			$template = 'view-4';
			break;
			case 'style3':
			$template = 'view-3';
			break;
			case 'style2':
			$template = 'view-2';
			break;
			default:
			$template = 'view-1';
			break;
		}

		return $this->rt_template( $template, $data );
	}
}