<?php
/**
 * This file can be overridden by copying it to yourtheme/elementor-custom/title/class.php
 * 
 * @author  RadiusTheme
 * @since   1.0
 * @version 1.0
 */

namespace radiustheme\Aeen_Core;

use Elementor\Utils;
use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Background;

if ( ! defined( 'ABSPATH' ) ) exit;

class Contact_Box extends Custom_Widget_Base {

	public function __construct( $data = [], $args = null ){
		$this->rt_name = __( 'RT Contact', 'aeen-core' );
		$this->rt_base = 'rt-contact-box';
		parent::__construct( $data, $args );
	}

	public function rt_fields(){
		$fields = array(

			array(
					'mode'    => 'section_start',
					'id'      => 'sec_general_phone',
					'label'   => esc_html__( 'Phone', 'aeen-core' ),
				),

			array(
				'type'    => Controls_Manager::TEXT,
				'id'      => 'phone_label',
				'label'   => esc_html__( 'Phone label', 'aeen-core' ),
				'default' => esc_html__( 'Office Phone', 'aeen-core' ),
			),
			array(
				'type'    => Controls_Manager::TEXT,
				'id'      => 'phone',
				'label'   => esc_html__( 'Phone', 'aeen-core' ),
				'default' => __('(+011) 948-5481', 'aeen-core'),
			),
			array(
					'mode' => 'section_end',
				),
			array(
					'mode'    => 'section_start',
					'id'      => 'sec_general_email',
					'label'   => esc_html__( 'Email', 'aeen-core' ),
				),

			array(
				'type'    => Controls_Manager::TEXT,
				'id'      => 'email_label',
				'label'   => esc_html__( 'Email label', 'aeen-core' ),
				'default' => esc_html__( 'Mail Us', 'aeen-core' ),
			),

			array(
				'type'    => Controls_Manager::TEXT,
				'id'      => 'email',
				'label'   => esc_html__( 'Email', 'aeen-core' ),
				'default' => esc_html__( 'support@ourtheme.com', 'aeen-core' ),
			),
			array(
				'mode' => 'section_end',
			),

			array(
					'mode'    => 'section_start',
					'id'      => 'sec_general_address',
					'label'   => esc_html__( 'Address', 'aeen-core' ),
				),
			array(
				'type'    => Controls_Manager::TEXT,
				'id'      => 'address_label',
				'label'   => esc_html__( 'Address label', 'aeen-core' ),
				'default' => esc_html__('Address', 'aeen-core' ),
			),
			array(
				'type'    => Controls_Manager::TEXTAREA,
				'id'      => 'address',
				'label'   => esc_html__( 'Address', 'aeen-core' ),
				'default' => esc_html__( 'Advokat Inc., 103, Mallin Street New Youk, NY 100 254', 'aeen-core' ),
			),
			array(
				'mode' => 'section_end',
			),

			array(
					'mode'    => 'section_start',
					'id'      => 'sec_title_style',
					'label'   => esc_html__( 'Layout Title', 'aeen-core' ),
					'tab'     => Controls_Manager::TAB_STYLE,
				),
			array(
					'type'    => Controls_Manager::COLOR,
					'id'      => 'title_color',
					'label'   => __( 'Title Color', 'aeen-core' ),
					'default' => '',
					'selectors' => array(
							'{{WRAPPER}} .address-items li .media .media-body .item-title' => 'color: {{VALUE}}',							
						),
				),		
			array( 
					'mode'      => 'group',
					'type'      => Group_Control_Typography::get_type(),
					'name'      => 'title_typo',
					'label'     => esc_html__( 'Title Typography', 'aeen-core' ),
					'selector'  => '{{WRAPPER}} .address-items li .media .media-body .item-title',
				),			
			array(
				'mode' => 'section_end',
			),

			array(
				'mode'    => 'section_start',
				'id'      => 'sec_lable_style',
				'label'   => esc_html__( 'Label', 'aeen-core' ),
				'tab'     => Controls_Manager::TAB_STYLE,

				'condition'   => array('layout' => array( 'layout1' ) ),
			),
			array(
				'type' 				=> Controls_Manager::SLIDER,
				'mode' 				=> 'responsive',
				'id'      		=> 'bottom_email_spacing',
				'label'   		=> __( 'Labal Bottom Spacing', 'aeen-core' ),
				'size_units' => array( 'px' ),				
				'default' => array(
				'unit' => 'px',
				'size' => 20,
				),
					'selectors' => array(
						'{{WRAPPER}} .lab-title' => 'margin-bottom: {{SIZE}}{{UNIT}};',						
					)
				),
			array(
					'type'    => Controls_Manager::COLOR,
					'id'      => 'email_lab_color',
					'label'   => __( 'Labal Color', 'aeen-core' ),
					'default' => '',
					'selectors' => array(
							'{{WRAPPER}} .lab-title' => 'color: {{VALUE}}',							
							'{{WRAPPER}} .item-icon i' => 'color: {{VALUE}}',							
						),
				),		
			array( 
					'mode'      => 'group',
					'type'      => Group_Control_Typography::get_type(),
					'name'      => 'email_typo',
					'label'     => esc_html__( 'Labal Typography', 'aeen-core' ),
					'selector'  => '{{WRAPPER}} .lab-title',
				),	

			array(
				'mode' => 'section_end',
			),
			array(
					'mode'    => 'section_start',
					'id'      => 'sec_content_style',
					'label'   => esc_html__( 'Content', 'aeen-core' ),
					'tab'     => Controls_Manager::TAB_STYLE,
				),
			array(
				'type'    => Controls_Manager::COLOR,
				'id'      => 'content_color',
				'label'   => __( 'Content Color', 'aeen-core' ),
				'default' => '',
				'selectors' => array(
						'{{WRAPPER}} .address-items li .media .media-body p' => 'color: {{VALUE}}',							
						
					),
			),		
			array( 
					'mode'      => 'group',
					'type'      => Group_Control_Typography::get_type(),
					'name'      => 'content_typo',
					'label'     => esc_html__( 'Content Typography', 'aeen-core' ),
					'selector'  => '{{WRAPPER}} .content-style li',
				),			
					

			array(
				'mode' => 'section_end',
			),
		);
		return $fields;
	}

	protected function render() {
		$data = $this->get_settings();

		$template = 'view-1';

		return $this->rt_template( $template, $data );
	}
}