<?php
/**
 * This file can be overridden by copying it to yourtheme/elementor-custom/about-box/class.php
 * 
 * @author  RadiusTheme
 * @since   1.0
 * @version 1.0
 */

namespace radiustheme\Aeen_Core;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Background;


if ( ! defined( 'ABSPATH' ) ) exit;

class Experience_Box extends Custom_Widget_Base {

	public function __construct( $data = [], $args = null ){
		$this->rt_name = __( 'Experience Box', 'aeen-core' );
		$this->rt_base = 'rt-experience-box';
		parent::__construct( $data, $args );
	}

	public function rt_fields(){
		$fields = array(
			array(
				'id'      => 'sec_experience_box',
				'mode'    => 'section_start',
				'label'   => __( 'Experience Box', 'aeen-core' ),
			),

			// Image 1
			array(
				'type'    => Controls_Manager::MEDIA,
				'id'      => 'image1',
				'label'   => esc_html__( 'Image', 'aeen-core' ),
				'default' => [
                    'url' => $this->rt_placeholder_image(),
                ],
				'description' => esc_html__( 'Recommended full image', 'aeen-core' ),
			),
			array(
				'type'    => Controls_Manager::TEXT,
				'id'      => 'year',
				'label'   => __( 'Year', 'aeen-core' ),
				'default' => __( '14', 'aeen-core' ),
			),
			array(
				'type'    => Controls_Manager::TEXT,
				'id'      => 'year_text',
				'label'   => __( 'Year Text', 'aeen-core' ),
				'default' => __( 'Years', 'aeen-core' ),
			),
			array(
				'type'    => Controls_Manager::TEXT,
				'id'      => 'experience',
				'label'   => __( 'Experience', 'aeen-core' ),
				'default' => __( 'Experience', 'aeen-core' ),
			),
			array(
				'mode' => 'section_end',
			),

			// Style
			array(
				'id'      => 'box_style',
				'mode'    => 'section_start',
				'tab'     => Controls_Manager::TAB_STYLE,
				'label'   => __( 'Box Style', 'aeen-core' ),
			),
			array(
				'id'      => 'box_overlay',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Box Overlay', 'aeen-core' ),
				'selectors' => array( '{{WRAPPER}} .about-left-thumb::before' => 'background: {{VALUE}} !important' ),
			),
			array(
				'id'      => 'shape1',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Shape 1', 'aeen-core' ),
				'selectors' => array( 
						'{{WRAPPER}} .experience-border-right::after' => 'background: {{VALUE}} !important',
						'{{WRAPPER}} .experience-border-right::before' => 'background: {{VALUE}} !important',
						'{{WRAPPER}} .experience-border::before' => 'background: {{VALUE}} !important',
						'{{WRAPPER}} .experience-border-left::before' => 'background: {{VALUE}} !important',
						'{{WRAPPER}} .experience-border-left::after' => 'background: {{VALUE}} !important',
					 ),
			),
			array(
				'id'      => 'shape2',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Shape 2', 'aeen-core' ),
				'selectors' => array( '{{WRAPPER}} .about-left-thumb::after' => 'border-color: {{VALUE}} !important' ),
			),
			array(
				'mode' => 'section_end',
			),

			// Year
			array(
				'id'      => 'year_style',
				'mode'    => 'section_start',
				'tab'     => Controls_Manager::TAB_STYLE,
				'label'   => __( 'Year Style', 'aeen-core' ),
			),
			array(
				'id'      => 'year_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Color', 'aeen-core' ),
				'selectors' => array( '{{WRAPPER}} .experience>.years' => 'color: {{VALUE}} !important' ),
			),
			array(
				'mode'     => 'group',
				'type'     => Group_Control_Typography::get_type(),
				'name'     => 'year_typo',
				'label'    => __( 'Typography', 'aeen-core' ),
				'selector' => '{{WRAPPER}} .experience>.years',
			),
			array(
				'mode' => 'section_end',
			),

			// Year Text
			array(
				'id'      => 'year_text_style',
				'mode'    => 'section_start',
				'tab'     => Controls_Manager::TAB_STYLE,
				'label'   => __( 'Year Text Style', 'aeen-core' ),
			),
			array(
				'id'      => 'year_text_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Color', 'aeen-core' ),
				'selectors' => array( '{{WRAPPER}} .experience>.title' => 'color: {{VALUE}} !important' ),
			),
			array(
				'mode'     => 'group',
				'type'     => Group_Control_Typography::get_type(),
				'name'     => 'year_text_typo',
				'label'    => __( 'Typography', 'aeen-core' ),
				'selector' => '{{WRAPPER}} .experience>.title',
			),
			array(
				'mode' => 'section_end',
			),
			
			// Experience
			array(
				'id'      => 'experience_style',
				'mode'    => 'section_start',
				'tab'     => Controls_Manager::TAB_STYLE,
				'label'   => __( 'Experience Style', 'aeen-core' ),
			),
			array(
				'id'      => 'experience_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Color', 'aeen-core' ),
				'selectors' => array( '{{WRAPPER}} .experience>.title>span' => 'color: {{VALUE}} !important' ),
			),
			array(
				'mode'     => 'group',
				'type'     => Group_Control_Typography::get_type(),
				'name'     => 'experience_typo',
				'label'    => __( 'Typography', 'aeen-core' ),
				'selector' => '{{WRAPPER}} .experience>.title>span',
			),
			array(
				'mode' => 'section_end',
			),
		);
		return $fields;
	}

	protected function render() {
		$data = $this->get_settings();

		$template = 'view';

		return $this->rt_template( $template, $data );
	}
}