<?php
/**
 * This file can be overridden by copying it to yourtheme/elementor-custom/title/class.php
 * 
 * @author  RadiusTheme
 * @since   1.0
 * @version 1.0
 */

namespace radiustheme\Aeen_Core;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Background;

if ( ! defined( 'ABSPATH' ) ) exit;

class Rt_History extends Custom_Widget_Base {

	public function __construct( $data = [], $args = null ){
		$this->rt_name = __( 'RT History', 'aeen-core' );
		$this->rt_base = 'rt-history';
		parent::__construct( $data, $args );
	}

	public function rt_fields(){

		$repeater = new \Elementor\Repeater();
		$repeater->add_control(
			'history_year', [
				'type'        => Controls_Manager::TEXT,
				'label'       => esc_html__( 'Year', 'aeen-core' ),
				'default'     => __( '2013', 'aeen-core' ),
				'label_block' => true,
			]
		);
		$repeater->add_control(
			'history_title', [
				'type'        => Controls_Manager::TEXT,
				'label'       => esc_html__( 'Title', 'aeen-core' ),
				'default'     => __( 'Established', 'aeen-core' ),
				'label_block' => true,
			]
		);
		$repeater->add_control(
			'history_desc', [
				'type'        => Controls_Manager::TEXTAREA,
				'label'       => esc_html__( 'Description', 'aeen-core' ),
				'default'     => __( 'Grursus mal suada faci lisis Lorem ipsum dolarorit more a ametion consectetur elit. Vesti at bulum nec odio aea the dumm ipsumm is ipsum dolocons fadolorit consectetur elit.', 'aeen-core' ),
				'label_block' => true,
			]
		);
		$fields = array(
			array(
				'id'      => 'sec_rt_history',
				'mode'    => 'section_start',
				'label'   => esc_html__( 'History', 'aeen-core' ),
			),
			array (
				'type'    => Controls_Manager::REPEATER,
				'id'      => 'history_items',
				'label'   => esc_html__( 'Add as many history list as you want', 'aeen-core' ),
				'fields' => $repeater->get_controls(),
				'default' => [
					['history_title' => __( 'Established', 'aeen-core' ) ],	         
					['history_title' => __( 'Office Founded', 'aeen-core' ) ],	         
					['history_title' => __( 'Big Restructuring..', 'aeen-core' ) ],	         
					['history_title' => __( 'We Have Opened Two Offices', 'aeen-core' ) ],        
					['history_title' => __( 'Our First Government Deal', 'aeen-core' ) ],        
		       ],
			),
			array(
				'mode' => 'section_end',
			),
			
			// Style
			array(
				'id'      => 'year_style',
				'mode'    => 'section_start',
				'tab'     => Controls_Manager::TAB_STYLE,
				'label'   => __( 'Year Style', 'aeen-core' ),
			),
			array(
				'id'        => 'year_heading',
				'type'      => Controls_Manager::HEADING,
				'label'     => __( 'Year', 'aeen-core' ),
				'separator' => 'before',
			),
			array(
				'id'        => 'year_color',
				'type'      => Controls_Manager::COLOR,
				'label'     => __( 'Color', 'aeen-core' ),
				'selectors' => array( '{{WRAPPER}} .history-inner-layout1 .history-box-layout1 .item-year' => 'color: {{VALUE}}' ),
			),
			array(
				'mode'     => 'group',
				'type'     => Group_Control_Typography::get_type(),
				'name'     => 'year_typo',
				'label'    => __( 'Typography', 'aeen-core' ),
				'selector' => '{{WRAPPER}} .history-inner-layout1 .history-box-layout1 .item-year',
			),
			array(
				'mode' => 'section_end',
			),
			
			// Title
			array(
				'id'      => 'title_style',
				'mode'    => 'section_start',
				'tab'     => Controls_Manager::TAB_STYLE,
				'label'   => __( 'Title Style', 'aeen-core' ),
			),
			array(
				'id'        => 'title_heading',
				'type'      => Controls_Manager::HEADING,
				'label'     => __( 'Title', 'aeen-core' ),
				'separator' => 'before',
			),
			array(
				'id'        => 'title_color',
				'type'      => Controls_Manager::COLOR,
				'label'     => __( 'Color', 'aeen-core' ),
				'selectors' => array( '{{WRAPPER}} .history-inner-layout1 .history-box-layout1 .item-content h3' => 'color: {{VALUE}}' ),
			),
			array(
				'mode'     => 'group',
				'type'     => Group_Control_Typography::get_type(),
				'name'     => 'title_typo',
				'label'    => __( 'Typography', 'aeen-core' ),
				'selector' => '{{WRAPPER}} .history-inner-layout1 .history-box-layout1 .item-content h3',
			),
			array(
				'mode' => 'section_end',
			),
			array(
				'id'      => 'desc_style',
				'mode'    => 'section_start',
				'tab'     => Controls_Manager::TAB_STYLE,
				'label'   => __( 'Description Style', 'aeen-core' ),
			),
			array(
				'id'        => 'desc_heading',
				'type'      => Controls_Manager::HEADING,
				'label'     => __( 'Description', 'aeen-core' ),
				'separator' => 'before',
			),
			array(
				'id'        => 'desc_color',
				'type'      => Controls_Manager::COLOR,
				'label'     => __( 'Color', 'aeen-core' ),
				'selectors' => array( '{{WRAPPER}} .history-inner-layout1 .history-box-layout1 .item-content p' => 'color: {{VALUE}}' ),
			),
			array(
				'mode'     => 'group',
				'type'     => Group_Control_Typography::get_type(),
				'name'     => 'desc_typo',
				'label'    => __( 'Typography', 'aeen-core' ),
				'selector' => '{{WRAPPER}} .history-inner-layout1 .history-box-layout1 .item-content p',
			),
			array(
				'mode' => 'section_end',
			),
		);
		return $fields;
	}

	protected function render() {
		$data = $this->get_settings();

		$template = 'view';

		return $this->rt_template( $template, $data );
	}
}