<?php
/**
 * This file can be overridden by copying it to yourtheme/elementor-custom/title/class.php
 * 
 * @author  RadiusTheme
 * @since   1.0
 * @version 1.0
 */

namespace radiustheme\Aeen_Core;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Background;

if ( ! defined( 'ABSPATH' ) ) exit;

class Icon_List extends Custom_Widget_Base {

	public function __construct( $data = [], $args = null ){
		$this->rt_name = __( 'RT Icon List', 'aeen-core' );
		$this->rt_base = 'rt-icon-list';
		parent::__construct( $data, $args );
	}

	public function rt_fields(){
		$repeater = new \Elementor\Repeater();
		$repeater->add_control(
			'icon_box_title', [
				'type'    => Controls_Manager::TEXT,
				'label'   => esc_html__( 'Title', 'aeen-core' ),
				'default' => esc_html__( 'Impenetrable foliage of my trees, and but a few stray gleams.', 'aeen-core' ),
			]
		);
		$fields = array(
			array(
				'mode'    => 'section_start',
				'id'      => 'sec_general',
				'label'   => esc_html__( 'General', 'aeen-core' ),
			),
			array(
				'type'    => Controls_Manager::SELECT2,
				'id'      => 'layout',
				'label'   => esc_html__( 'Layout', 'aeen-core' ),
				'options' => array(
					'layout1' => esc_html__( 'Layout 1', 'aeen-core' ),					
					'layout2' => esc_html__( 'Layout 2', 'aeen-core' ),					
				),
				'default' => 'layout1',
			),		
			array(
				'type'    => Controls_Manager::SELECT2,
				'id'      => 'icontype',
				'label'   => esc_html__( 'Icon Type', 'aeen-core' ),
				'options' => array(
					'icon'  => esc_html__( 'Icon', 'aeen-core' ),
					'image' => esc_html__( 'Custom Image', 'aeen-core' ),
				),
				'default' => 'icon',
				'condition' => array( 'layout' => 'layout1' ),
			),
			array(
				'type'    => Controls_Manager::ICONS,
				'id'      => 'list_icon',
				'label'   => esc_html__( 'Icon', 'aeen-core' ),
				'default' => [
			      'value' => 'fas fa-smile-wink',
			      'library' => 'fa-solid',
			  ],
			  'condition' => array( 'layout' => 'layout1' ),	
			),	
			array(
				'type'    => Controls_Manager::TEXT,
				'id'      => 'list_title',
				'label'   => esc_html__( 'Title', 'aeen-core' ),
				'default' => esc_html__( 'Qualified Workers', 'aeen-core' ),
				'condition' => array( 'layout' => 'layout1' ),
			),
			array(
				'type'    => Controls_Manager::TEXTAREA,
				'id'      => 'list_description',
				'label'   => esc_html__( 'Description', 'aeen-core' ),
				'default' => esc_html__( 'Grursus mal suada faci is Lorem ipsum dolarorit consectetur the elit.', 'aeen-core' ),
				'condition' => array( 'layout' => 'layout1' ),
			),
			array (
				'type'    => Controls_Manager::REPEATER,
				'id'      => 'rt_icon_boxes',
				'label'   => esc_html__( 'Add as many boxes as you want', 'aeen-core' ),
				'fields' => $repeater->get_controls(),
				'default' => [
					['icon_box_title' => __( 'Impenetrable foliage of my trees, and but a few stray gleams.', 'aeen-core' ) ],	         
					['icon_box_title' => __( 'A wonderful serenity has taken possession of my entire soul.', 'aeen-core' ) ],	         
					['icon_box_title' => __( 'I should be incapable of drawing a single stroke at the present moment.', 'aeen-core' ) ],       
		       ],
		       'condition' => array( 'layout' => array( 'layout2' ) ),
			),
			array(
				'mode' => 'section_end',
			),
			// Title style
			array(
			    'mode'    => 'section_start',
			    'id'      => 'counter_style',
			    'label'   => esc_html__( 'Icon Style', 'aeen-core' ),
			    'tab'     => Controls_Manager::TAB_STYLE,
			    'condition'   =>  array( 'layout' => array( 'layout1' )),
			),      			
			array(
			    'type'    	=> Controls_Manager::COLOR,
			    'id'      	=> 'counter_icon_color',
			    'label'   	=> __( 'Icon Color', 'aeen-core' ),
			    'default' 	=> '',                       
			    'selectors' => array(
			        '{{WRAPPER}} .progress-box-layout1 .item-icon i:before' => 'color: {{VALUE}}',      
			        '{{WRAPPER}} .practice-info-box i' => 'color: {{VALUE}}',      
			        ),
			),  	
			array( 
			    'mode'      => 'group',
			    'type'      => Group_Control_Typography::get_type(),
			    'name'      => 'counter_icon_font_size',                
			    'label'     => esc_html__( 'Typography', 'aeen-core' ),
			    'selector'  =>'{{WRAPPER}} .practice-info-box i',
			),
			array(
			    'type'    => Controls_Manager::DIMENSIONS,
			    'size_units' => [ 'px', '%', 'em' ],
			    'id'      => 'counter_icon_padding',
			    'label'   => __( 'Padding', 'aeen-core' ),
			    'selectors' => array(
			        '{{WRAPPER}} .progress-box-layout1 .item-icon' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',                   
			        '{{WRAPPER}} .practice-info-box i' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',                   
			                           
			    ),
			    'separator' => 'before',
			),  
			array(
			    'type'    => Controls_Manager::DIMENSIONS,
			    'size_units' => [ 'px', '%', 'em' ],
			    'id'      => 'counter_icon_margin',
			    'label'   => __( 'Margin', 'aeen-core' ),                 
			    'selectors' => array(
			        '{{WRAPPER}} .progress-box-layout1 .item-icon' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',                    
			        '{{WRAPPER}} .practice-info-box i' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',                    
			    ),
			    'separator' => 'before',
			),  
			
			array(
				'mode' => 'section_end',
			),
			// Title style
			array(
			    'mode'    => 'section_start',
			    'id'      => 'counter_title_style',
			    'label'   => esc_html__( 'Title  Style', 'aeen-core' ),
			    'tab'     => Controls_Manager::TAB_STYLE,
			),      
			array(
			    'type'    	=> Controls_Manager::COLOR,
			    'id'      	=> 'count_title_color',
			    'label'   	=> __( 'Color', 'aeen-core' ),
			    'default' 	=> '',                       
			    'selectors' => array(
			        '{{WRAPPER}} .progress-box-layout1 .item-content .item-title' => 'color: {{VALUE}}',     
			        '{{WRAPPER}} .progress-box-layout2 .item-title' => 'color: {{VALUE}}',     
			        '{{WRAPPER}} .rt-icon-box ul.rt-icon-box.practice-list-box li' => 'color: {{VALUE}}',     
			        '{{WRAPPER}} .rt-icon-box ul.rt-icon-box.practice-list-box li:before' => 'color: {{VALUE}}',     
			        '{{WRAPPER}} .practice-info-box h4' => 'color: {{VALUE}}',     
			        ),
			),  
			array( 
			    'mode'      => 'group',
			    'type'      => Group_Control_Typography::get_type(),
			    'name'      => 'counter_title_font_size',                
			    'label'     => esc_html__( 'Typography', 'aeen-core' ),
			    'selector'  =>'{{WRAPPER}} .progress-box-layout1 .item-content .item-title, {{WRAPPER}} .progress-box-layout2 .item-title, {{WRAPPER}} .rt-icon-box ul.rt-icon-box.practice-list-box li, {{WRAPPER}} .practice-info-box h4',
			),
			array(
			    'type'    => Controls_Manager::DIMENSIONS,
			    'size_units' => [ 'px', '%', 'em' ],
			    'id'      => 'counter_title_padding',
			    'label'   => __( 'Padding', 'aeen-core' ),
			    'selectors' => array(
			        '{{WRAPPER}} .progress-box-layout1 .item-content .item-title' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',                  
			        '{{WRAPPER}} .progress-box-layout2 .item-title' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',                  
			        '{{WRAPPER}} .practice-info-box h4' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',                  
			                           
			    ),
			    'separator' => 'before',
			),  
			array(
			    'type'    => Controls_Manager::DIMENSIONS,
			    'size_units' => [ 'px', '%', 'em' ],
			    'id'      => 'counter_title_margin',
			    'label'   => __( 'Margin', 'aeen-core' ),                 
			    'selectors' => array(
			        '{{WRAPPER}} .progress-box-layout1 .item-content .item-title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',                    
			        '{{WRAPPER}} .progress-box-layout2 .item-title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',                    
			        '{{WRAPPER}} .practice-info-box h4' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',                    
			    ),
			    'separator' => 'before',
			),
			array(
				'mode' => 'section_end',
			),
			// Description style
			array(
			    'mode'    => 'section_start',
			    'id'      => 'content_style',
			    'label'   => esc_html__( 'Description', 'aeen-core' ),
			    'tab'     => Controls_Manager::TAB_STYLE,
			    'condition'   =>  array( 'layout' => array( 'layout1' )),
			),      
			array(
			    'type'    	=> Controls_Manager::COLOR,
			    'id'      	=> 'content_color',
			    'label'   	=> __( 'Color', 'aeen-core' ),
			    'default' 	=> '',                       
			    'selectors' => array(
			        '{{WRAPPER}} .practice-info-box p' => 'color: {{VALUE}}',    
			        ),
			),  
			array( 
			    'mode'      => 'group',
			    'type'      => Group_Control_Typography::get_type(),
			    'name'      => 'content_typho',                
			    'label'     => esc_html__( 'Typography', 'aeen-core' ),
			    'selector'  =>'{{WRAPPER}} .practice-info-box p',
			),  
			array(
				'mode' => 'section_end',
			),
		);
		return $fields;
	}

	protected function render() {
		$data = $this->get_settings();

		switch ( $data['layout'] ) {
			case 'layout2':
			$template = 'view-2';
			break;
			default:
			$template = 'view-1';
			break;
		}

		return $this->rt_template( $template, $data );
	}
}