<?php
/**
 * This file can be overridden by copying it to yourtheme/elementor-custom/title/class.php
 * 
 * @author  RadiusTheme
 * @since   1.0
 * @version 1.0
 */

namespace radiustheme\Aeen_Core;

use Elementor\Utils;
use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Image_Size;

if ( ! defined( 'ABSPATH' ) ) exit;

class Service_Box extends Custom_Widget_Base {

	public function __construct( $data = [], $args = null ){
		$this->rt_name = __( 'RT Service Box', 'aeen-core' );
		$this->rt_base = 'rt-service-box';
		parent::__construct( $data, $args );
	}

	public function rt_load_scripts(){
		wp_enqueue_style(  'owl-carousel' );
		wp_enqueue_style(  'owl-theme' );

		wp_enqueue_script( 'owl-carousel' );
	}

	public function rt_fields(){
		$repeater1 = new \Elementor\Repeater();
		$repeater1->add_control(
			'sbox_icon', array(
				'type'        => \Elementor\Controls_Manager::ICONS,
				'label'       => esc_html__( 'Icon', 'aeen-core' ),
				'description' => esc_html__( 'Select icon', 'aeen-core' ),
				'default'     => [
					'value'   => 'flaticon-search',
					'library' => 'fa-solid',
				],
            )
		);

		$repeater1->add_control(
			'sbox_title', array(
				'type'    => \Elementor\Controls_Manager::TEXT,
				'label'   => esc_html__( 'Title', 'aeen-core' ),
				'default' => 'Analyzing The Case',
            )
		);

		$repeater1->add_control(
			'sbox_content', array(
				'type'    => \Elementor\Controls_Manager::TEXTAREA,
				'label'   => esc_html__( 'Content (For desktop and tab)', 'aeen-core' ),
				'default' => 'Grursus mal suada faci lisis Lorem ipsum is at as the dolarorit more and ametion consectetur elit. ipsum that consectetur elit.',
            )
		);

		$repeater1->add_control(
			'sbox_tablet_col', array(
				'type'    => \Elementor\Controls_Manager::SWITCHER,
				'label'       => esc_html__( 'Tablet Column', 'aeen-core' ),
				'label_on'    => esc_html__( 'Full', 'aeen-core' ),
				'label_off'   => esc_html__( 'Half', 'aeen-core' ),
				'default'     => 'no',
				'description' => esc_html__( 'Tablet Column. Default: Half', 'aeen-core' ),
            )
		);

		// style two 
		$repeater = new \Elementor\Repeater();
		$repeater->add_control(
			'sbox_image', array(
				'type'    => Controls_Manager::MEDIA,
				'label'   => esc_html__( 'Image', 'aeen-core' ),
				'description' => esc_html__( 'Image size should be 1920x820 px', 'aeen-core' ),
            )
		);
		$repeater->add_control(
			'sbox_two_icon', array(
				'type'        => Controls_Manager::ICONS,
				'label'       => esc_html__( 'Icon', 'aeen-core' ),
				'description' => esc_html__( 'Select icon', 'aeen-core' ),
				'default'     => [
					'value'   => 'flaticon-search',
					'library' => 'fa-solid',
				],
            )
		);
		$repeater->add_control(
			'sbox_two_title', array(
				'type'    => Controls_Manager::TEXT,
				'label'   => esc_html__( 'Title', 'aeen-core' ),
				'default' => 'Analyzing The Case',
            )
		);
		$repeater->add_control(
			'sbox_two_content', array(
				'type'    => Controls_Manager::TEXTAREA,
				'label'   => esc_html__( 'Content (For desktop and tab)', 'aeen-core' ),
				'default' => 'Grursus mal suada faci lisis Lorem ipsum is at as the dolarorit more and ametion consectetur elit. ipsum that consectetur elit.',
            )
		);
		$repeater->add_control(
			'sbox_two_url', array(
				'type' => Controls_Manager::URL,
				'placeholder' => __( 'https://your-link.com', 'aeen-core' ),
				'show_external' => true,
				'default' => [
					'url' => '',
					'is_external' => true,
					'nofollow' => true,
				],
            )
		);
		$repeater->add_control(
			'animation_delay', array(
				'type'    => Controls_Manager::NUMBER,
				'label'   =>esc_html__( 'Animation Delay', 'aeen-core' ),
				'default' => 0.2,
				'description' =>esc_html__( 'Animation delay in second', 'aeen-core' ),
            )
		);

		// repeater 3
		$repeater3 = new \Elementor\Repeater();
		$repeater3->add_control(
			'sbox_three_image', array(
				'type'    => Controls_Manager::MEDIA,
				'label'   => esc_html__( 'Image', 'aeen-core' ),
				'description' => esc_html__( 'Add Image', 'aeen-core' ),
            )
		);

		$repeater3->add_control(
			'sbox_three_title', array(
				'type'    => Controls_Manager::TEXT,
				'label'   => esc_html__( 'Title', 'aeen-core' ),
				'default' => 'Analyzing The Case',
            )
		);

		$repeater3->add_control(
			'sbox_three_content', array(
				'type'    => Controls_Manager::TEXTAREA,
				'label'   => esc_html__( 'Content (For desktop and tab)', 'aeen-core' ),
				'default' => 'Grursus mal suada faci lisis Lorem the as ipsum dolarorit consectetur.',
            )
		);

		// repeater 4
		$repeater4 = new \Elementor\Repeater();
		$repeater4->add_control(
			'sbox_four_icon', array(
				'type'        => Controls_Manager::ICONS,
				'label'       => esc_html__( 'Icon', 'aeen-core' ),
				'description' => esc_html__( 'Select icon', 'aeen-core' ),
				'default'     => [
					'value'   => 'flaticon-search',
					'library' => 'fa-solid',
				],
            )
		);

		$repeater4->add_control(
			'sbox_four_title', array(
				'type'    => Controls_Manager::TEXT,
				'label'   => esc_html__( 'Title', 'aeen-core' ),
				'default' => 'Family Law',
            )
		);

		$repeater4->add_control(
			'sbox_four_content', array(
				'type'    => Controls_Manager::TEXTAREA,
				'label'   => esc_html__( 'Content (For desktop and tab)', 'aeen-core' ),
				'default' => 'Grursus mal suada faci lisis Lorem ipsum dolarorit is more a ametion consectetur elit. Vesti at bulum themal fadolorit consectetur elit.',
            )
		);

		$repeater4->add_control(
			'sbox_four_url', array(
				'type' => Controls_Manager::URL,
				'placeholder' => __( 'https://your-link.com', 'aeen-core' ),
				'show_external' => true,
				'default' => [
					'url' => '',
					'is_external' => true,
					'nofollow' => true,
				],
            )
		);

		$repeater4->add_control(
			'animation_delay', array(
				'type'    => Controls_Manager::NUMBER,
				'label'   =>esc_html__( 'Animation Delay', 'aeen-core' ),
				'default' => 0.2,
				'description' =>esc_html__( 'Animation delay in second', 'aeen-core' ),
            )
		);

		// repeater 5
		$repeater5 = new \Elementor\Repeater();
		$repeater5->add_control(
			'sbox5_icon', array(
				'type'        => Controls_Manager::ICONS,
				'label'       => esc_html__( 'Icon', 'aeen-core' ),
				'description' => esc_html__( 'Select icon', 'aeen-core' ),
				'default'     => [
					'value'   => 'flaticon-search',
					'library' => 'fa-solid',
				],
            )
		);

		$repeater5->add_control(
			'sbox5_title', array(
				'type'    => Controls_Manager::TEXT,
				'label'   => esc_html__( 'Title', 'aeen-core' ),
				'default' => 'Analyzing The Case',
            )
		);

		$repeater5->add_control(
			'sbox5_sub_title', array(
				'type'    => Controls_Manager::TEXT,
				'label'   => esc_html__( 'Sub Title', 'aeen-core' ),
				'default' => 'Analyzing The Case',
            )
		);

		$repeater5->add_control(
			'sbox5_content', array(
				'type'    => Controls_Manager::TEXTAREA,
				'label'   => esc_html__( 'Content (For desktop and tab)', 'aeen-core' ),
				'default' => 'Grursus mal suada faci lisis Lorem ipsum is at as the dolarorit more and ametion consectetur elit. ipsum that consectetur elit.',
            )
		);

		$repeater5->add_control(
			'animation_delay', array(
				'type'    => Controls_Manager::NUMBER,
				'label'   =>esc_html__( 'Animation Delay', 'aeen-core' ),
				'default' => 0.2,
				'description' =>esc_html__( 'Animation delay in second', 'aeen-core' ),
            )
		);

		$repeater8 = new \Elementor\Repeater();

		$repeater8->add_control(
			'sbox8_image', array(
				'type'    => Controls_Manager::MEDIA,
				'label'   => esc_html__( 'Image', 'aeen-core' ),
				'description' => esc_html__( 'Image size should be 63x64 px', 'aeen-core' ),
            )
		);
		$repeater8->add_control(
			'sbox8_title', array(
				'type'    => Controls_Manager::TEXT,
				'label'   => esc_html__( 'Title', 'aeen-core' ),
				'default' => 'Discuss Your Legal Issue',
            )
		);
		$repeater8->add_control(
			'sbox8_content', array(
				'type'    => Controls_Manager::TEXTAREA,
				'label'   => esc_html__( 'Content (For desktop and tab)', 'aeen-core' ),
				'default' => 'Grursus mal suada faci lisis Lorem ipsum is a of dolarorit more a ametion consectetur elit. The Vesti the at bulum words.',
            )
		);

		$fields = array(
			array(
				'id'      => 'sec_general',
				'mode'    => 'section_start',
				'label'   => __( 'Service Box', 'aeen-core' ),
			),
			array(
				'type'    => Controls_Manager::SELECT2,
				'id'      => 'box_style',
				'label'   => esc_html__( 'Style', 'aeen-core' ),
				'options' => array(
					'style1' => esc_html__( 'Style 1', 'aeen-core' ),
					'style2' => esc_html__( 'Style 2', 'aeen-core' ),
					'style3' => esc_html__( 'Style 3', 'aeen-core' ),
					'style4' => esc_html__( 'Style 4', 'aeen-core' ),
					'style5' => esc_html__( 'Style 5', 'aeen-core' ),
					'style6' => esc_html__( 'Style 6', 'aeen-core' ),
					'style7' => esc_html__( 'Style 7', 'aeen-core' ),
					'style8' => esc_html__( 'Style 8', 'aeen-core' ),
				),
				'default' => 'style1',
			),

			// One Value
			array(
				'type'    => Controls_Manager::REPEATER,
				'id'      => 'service_boxes1',
				'label'   => esc_html__( 'Add as many boxes as you want', 'aeen-core' ),
				'title_field' => '{{{ sbox_title }}}',
				'fields' => $repeater1->get_controls(),
				'default' => array(
					array( 'sbox_icon' => 'flaticon-search', 'sbox_title' => 'Analyzing The Case', 'sbox_content' => 'Grursus mal suada faci lisis Lorem ipsum is at as the dolarorit more and ametion consectetur elit. ipsum that consectetur elit.' ),
					array( 'sbox_icon' => 'flaticon-book', 'sbox_title' => 'Taking Steps Forward', 'sbox_content' => 'Grursus mal suada faci lisis Lorem ipsum is at as the dolarorit more and ametion consectetur elit. ipsum that consectetur elit.' ),
					array( 'sbox_icon' => 'flaticon-law', 'sbox_title' => 'Court Of Law Success', 'sbox_content' => 'Grursus mal suada faci lisis Lorem ipsum is at as the dolarorit more and ametion consectetur elit. ipsum that consectetur elit.' ),
				),
				'condition' => array( 'box_style' => array( 'style1', 'style6' ) ),
			),


			// Two Value
			array(
				'type'    => Controls_Manager::REPEATER,
				'id'      => 'service_box_two',
				'label'   => esc_html__( 'Servics Box', 'aeen-core' ),
				'title_field' => '{{{ sbox_two_title }}}',
				'fields' => $repeater->get_controls(),
				'default' => array(
					['title' => 'Family Law', ],
					['title' => 'Civil Law', ],
					['title' => 'Education Law', ],
					['title' => 'Insurance Law', ],
					['title' => 'Analyzing The Case', ],
					['title' => 'Education Law', ],
				),
				'condition' => array( 'box_style' => array( 'style2' ) ),
			),

			// Service Box 3 Repeater
			array(
				'type'    => Controls_Manager::REPEATER,
				'id'      => 'service_box_three',
				'label'   => esc_html__( 'Add as many service box as you want', 'aeen-core' ),
				'title_field' => '{{{ sbox_three_title }}}',
				'fields' => $repeater3->get_controls(),
				'default' => array(
					['title' => 'Family Law', ],
					['title' => 'Civil Law', ],
					['title' => 'Education Law', ],
				),
				'condition' => array( 'box_style' => array( 'style3') ),
			),
			

			// Service Box 4 Repeater
			array(
				'type'    => Controls_Manager::REPEATER,
				'id'      => 'service_box_four',
				'label'   => esc_html__( 'Add as many service box as you want', 'aeen-core' ),
				'title_field' => '{{{ sbox_four_title }}}',
				'fields' => $repeater4->get_controls(),
				'default' => array(
					array( 'sbox_four_icon' => 'fas fa-balance-scale', 'sbox_four_title' => 'Family Law', 'sbox_four_content' => 'Grursus mal suada faci lisis Lorem ipsum dolarorit is more a ametion consectetur elit. Vesti at bulum themal fadolorit consectetur elit.', 'sbox_four_url' => '#' ),
					array( 'sbox_four_icon' => 'fas fa-school', 'sbox_four_title' => 'Civil Law', 'sbox_four_content' => 'Grursus mal suada faci lisis Lorem ipsum dolarorit is more a ametion consectetur elit. Vesti at bulum themal fadolorit consectetur elit.', 'sbox_four_url' => '#' ),
					array( 'sbox_four_icon' => 'fas fa-archway', 'sbox_four_title' => 'Criminal Law', 'sbox_four_content' => 'Grursus mal suada faci lisis Lorem ipsum dolarorit is more a ametion consectetur elit. Vesti at bulum themal fadolorit consectetur elit.', 'sbox_four_url' => '#' ),
					array( 'sbox_four_icon' => 'fas fa-business-time', 'sbox_four_title' => 'Business Law', 'sbox_four_content' => 'Grursus mal suada faci lisis Lorem ipsum dolarorit is more a ametion consectetur elit. Vesti at bulum themal fadolorit consectetur elit.', 'sbox_four_url' => '#' ),
					array( 'sbox_four_icon' => 'fas fa-atlas', 'sbox_four_title' => 'Education Law', 'sbox_four_content' => 'Grursus mal suada faci lisis Lorem ipsum dolarorit is more a ametion consectetur elit. Vesti at bulum themal fadolorit consectetur elit.', 'sbox_four_url' => '#' ),
					array( 'sbox_four_icon' => 'fas fa-assistive-listening-systems', 'sbox_four_title' => 'Insurance Defense', 'sbox_four_content' => 'Grursus mal suada faci lisis Lorem ipsum dolarorit is more a ametion consectetur elit. Vesti at bulum themal fadolorit consectetur elit.', 'sbox_four_url' => '#' ),
				),
				'condition' => array( 'box_style' => array( 'style4') ),
			),

			// Service Box 5 Repeater
			array(
				'type'    => Controls_Manager::REPEATER,
				'id'      => 'service_boxes5',
				'label'   => esc_html__( 'Add as many service box as you want', 'aeen-core' ),
				'title_field' => '{{{ sbox5_title }}}',
				'fields' => $repeater5->get_controls(),
				'default' => array(
					array( 'sbox5_icon' => 'fas fa-balance-scale', 'sbox5_title' => 'Legal Attorneys', 'sbox5_sub_title' => 'Qualified', 'sbox5_content' => 'Grursus mal suada faci lisis Lorem ipsum dolarorit more a ametion consectetur that more elit.' ),
					array( 'sbox5_icon' => 'fas fa-balance-scale', 'sbox5_title' => 'Years of Experience', 'sbox5_sub_title' => 'Over 30', 'sbox5_content' => 'Grursus mal suada faci lisis Lorem ipsum dolarorit more a ametion consectetur that more elit.' ),
					array( 'sbox5_icon' => 'fas fa-balance-scale', 'sbox5_title' => 'Law Certificate', 'sbox5_sub_title' => 'Our Awards', 'sbox5_content' => 'Grursus mal suada faci lisis Lorem ipsum dolarorit more a ametion consectetur that more elit.' ),
				),
				'condition' => array( 'box_style' => array( 'style5', 'style7' ) ),
			),

			array(
				'type'    => Controls_Manager::NUMBER,
				'id'      => 'excerpt_count',
				'label'   => esc_html__( 'Word count', 'aeen-core' ),
				'default' => 9,
				'description' => esc_html__( 'Maximum number of words', 'aeen-core' ),
				'condition'   => array( 'box_style' =>'style7' ),
			),


			// Service Box 8 Repeater
			array(
				'type'    => Controls_Manager::REPEATER,
				'id'      => 'service_box8',
				'label'   => esc_html__( 'Add as many service box as you want', 'aeen-core' ),
				'title_field' => '{{{ sbox8_title }}}',
				'fields' => $repeater8->get_controls(),
				'default' => array(
					array( 'sbox8_image' => '', 'sbox8_title' => 'Discuss Your Legal Issue', 'sbox8_content' => 'Grursus mal suada faci lisis Lorem ipsum is a of dolarorit more a ametion consectetur elit. The Vesti the at bulum words.' ),
					array( 'sbox8_image' => '', 'sbox8_title' => 'Recommended Lawyers', 'sbox8_content' => 'Grursus mal suada faci lisis Lorem ipsum is a of dolarorit more a ametion consectetur elit. The Vesti the at bulum words.' ),
					array( 'sbox8_image' => '', 'sbox8_title' => 'Choose Your Legal Advisor', 'sbox8_content' => 'Grursus mal suada faci lisis Lorem ipsum is a of dolarorit more a ametion consectetur elit. The Vesti the at bulum words.' ),
				),
				'condition' => array( 'box_style' => array( 'style8' ) ),
			),


			array(
				'mode' => 'section_end',
			),

			/* Styles
			==========================================*/
			array(
				'id'        => 'sbox_items_style',
				'mode'      => 'section_start',
				'tab'       => Controls_Manager::TAB_STYLE,
				'label'     => __( 'Box Background', 'aeen-core' ),
				'condition' => array( 'box_style' => array( 'style1' ) ),
			),
			array(
				'id'        => 'sbox_bg',
				'type'      => Controls_Manager::COLOR,
				'label'     => __( 'Background Color', 'aeen-core' ),
				'default'   => '',
				'selectors' => array( '{{WRAPPER}} .feature-box-layout1' => 'background-color: {{VALUE}}' ),
				'condition' => array( 'box_style' => array( 'style1', ) ),
			),
			array(
				'id'        => 'sbox_bg2',
				'type'      => Controls_Manager::COLOR,
				'label'     => __( 'Background Color 2', 'aeen-core' ),
				'default'   => '',
				'selectors' => array( '{{WRAPPER}} [class^="col-"]:nth-child(even) > .feature-box-layout1' => 'background-color: {{VALUE}}' ),
				'condition' => array( 'box_style' => array( 'style1' ) ),
			),
			array(
				'id'        => 'sbox_hov_bg',
				'type'      => Controls_Manager::COLOR,
				'label'     => __( 'Background hover color', 'aeen-core' ),
				'default'   => '',
				'selectors' => array( 
					'{{WRAPPER}} .feature-box-layout1:hover' => 'background-color: {{VALUE}}', 
					'{{WRAPPER}} [class^="col-"]:nth-child(even) > .feature-box-layout1:hover' => 'background-color: {{VALUE}}', 
				),
				'condition' => array( 'box_style' => array( 'style1' ) ),
			),

			array(
				'mode' => 'section_end',
			),

			// Icon Styles
			array(
				'id'      => 'sbox_icon_style',
				'mode'    => 'section_start',
				'tab'     => Controls_Manager::TAB_STYLE,
				'label'   => __( 'Icon', 'aeen-core' ),
				'condition' => array( 'box_style' => array( 'style1', 'style2', 'style4', 'style5', 'style6') ),
			),
			array(
				'id'        => 'sbox_icon_color',
				'type'      => Controls_Manager::COLOR,
				'label'     => __( 'Color', 'aeen-core' ),
				'default'   => '',
				'selectors' => array( 
					'{{WRAPPER}} .feature-box-layout1 .item-icon i' => 'color: {{VALUE}}', 
					'{{WRAPPER}} .service-box-layout1 .item-content .item-icon i' => 'color: {{VALUE}}', 
					'{{WRAPPER}} .practice-box-layout1 .item-icon i:before' => 'color: {{VALUE}}',  
					'{{WRAPPER}} .process-box-layout2 .item-icon i:before' => 'color: {{VALUE}}',  
					'{{WRAPPER}} .feature-box-layout2 .item-icon i:before' => 'color: {{VALUE}}',  
					'{{WRAPPER}} .service-box-layout1 .item-content .item-icon i:before' => 'color: {{VALUE}}',  
				),
			),
			array(
				'name'      => 'sbox_icon_typo',
				'mode'      => 'group',
				'type'      => Group_Control_Typography::get_type(),
				'label'     => __( 'Typography', 'aeen-core' ),
				'selector' => '{{WRAPPER}} .feature-box-layout1 .item-icon i:before, {{WRAPPER}} .service-box-layout1 .item-content .item-icon i:before, {{WRAPPER}} .practice-box-layout1 .item-icon i:before, {{WRAPPER}} .process-box-layout2 .item-icon i:before, {{WRAPPER}} .feature-box-layout2 .item-icon i:before',
			),
			array(
				'id'        => 'sbox_icon_hover_color',
				'type'      => Controls_Manager::COLOR,
				'label'     => __( 'Hover Color', 'aeen-core' ),
				'default'   => '',
				'selectors' => array( 
					'{{WRAPPER}} .feature-box-layout1:hover .item-icon i' => 'color: {{VALUE}}', 
					'{{WRAPPER}} .feature-box-layout2:hover .item-icon i' => 'color: {{VALUE}}', 
				),
			),
			array(
				'mode' => 'section_end',
			),

			// Title Styles
			array(
				'id'      => 'sbox_title_style',
				'mode'    => 'section_start',
				'tab'     => Controls_Manager::TAB_STYLE,
				'label'   => __( 'Title', 'aeen-core' ),
			),
			array(
				'id'        => 'sbox_title_color',
				'type'      => Controls_Manager::COLOR,
				'label'     => __( 'Color', 'aeen-core' ),
				'default'   => '',
				'selectors' => array( 
					'{{WRAPPER}} .feature-box-layout1 .item-title' => 'color: {{VALUE}}',
					'{{WRAPPER}} .service-box-layout1 .item-content .item-title a' => 'color: {{VALUE}}', 
					'{{WRAPPER}} .single-practice-box3 .item-title' => 'color: {{VALUE}}', 
					'{{WRAPPER}} .process-box-layout1 .item-title' => 'color: {{VALUE}}', 
					'{{WRAPPER}} .practice-box-layout1 .item-title a' => 'color: {{VALUE}}', 
					'{{WRAPPER}} .process-box-layout2 .item-title' => 'color: {{VALUE}}', 
					'{{WRAPPER}} .feature-box-layout2 .item-title' => 'color: {{VALUE}}', 
					'{{WRAPPER}} .why-choose-box .item-title' => 'color: {{VALUE}}', 
				),
			),
			array(
				'id'        => 'sbox_title_hover_color',
				'type'      => Controls_Manager::COLOR,
				'label'     => __( 'Hover Color', 'aeen-core' ),
				'default'   => '',
				'selectors' => array( 
					'{{WRAPPER}} .info-box-common .item-title' => 'color: {{VALUE}}',
					'{{WRAPPER}} .info-box-common .item-title a' => 'color: {{VALUE}}', 
					'{{WRAPPER}} .practice-box-layout1 .item-title a:hover' => 'color: {{VALUE}}', 
					'{{WRAPPER}} .service-box-layout1 .item-content .item-title a:hover' => 'color: {{VALUE}}', 
				),
				'condition' => array( 'box_style' => array( 'style2', 'style4' ) ),
			),
			array(
				'name'     => 'sbox_title_typo',
				'mode'     => 'group',
				'type'     => Group_Control_Typography::get_type(),
				'label'    => __( 'Typography', 'aeen-core' ),
				'selector' => '{{WRAPPER}} .feature-box-layout1 .item-title, {{WRAPPER}} .service-box-layout1 .item-content .item-title a, {{WRAPPER}} .process-box-layout1 .item-title, {{WRAPPER}} .practice-box-layout1 .item-title a, {{WRAPPER}} .process-box-layout2 .item-title, {{WRAPPER}} .feature-box-layout2 .item-title, {{WRAPPER}} .why-choose-box .item-title, {{WRAPPER}} .single-practice-box3 .item-title',
			),
			array(
				'mode' => 'section_end',
			),

			// Sub Title Styles
			array(
				'id'      => 'sbox_sub_title_style',
				'mode'    => 'section_start',
				'tab'     => Controls_Manager::TAB_STYLE,
				'label'   => __( 'Sub Title', 'aeen-core' ),
				'condition' => array( 'box_style' => array( 'style5' ) ),
			),
			array(
				'id'        => 'sbox_sub_title_color',
				'type'      => Controls_Manager::COLOR,
				'label'     => __( 'Color', 'aeen-core' ),
				'default'   => '',
				'selectors' => array( 
					'{{WRAPPER}} .process-box-layout2 .sub-title' => 'color: {{VALUE}}', 
				),
			),
			array(
				'name'     => 'sbox_sub_title_typo',
				'mode'     => 'group',
				'type'     => Group_Control_Typography::get_type(),
				'label'    => __( 'Typography', 'aeen-core' ),
				'selector' => '{{WRAPPER}} .process-box-layout2 .sub-title',
			),
			array(
				'mode' => 'section_end',
			),

			// Description Styles
			array(
				'id'      => 'sbox_desc_style',
				'mode'    => 'section_start',
				'tab'     => Controls_Manager::TAB_STYLE,
				'label'   => __( 'Description', 'aeen-core' ),
			),
			array(
				'id'        => 'sbox_desc_color',
				'type'      => Controls_Manager::COLOR,
				'label'     => __( 'Color', 'aeen-core' ),
				'default'   => '',
				'selectors' => array( 
					'{{WRAPPER}} .feature-box-layout1 p' => 'color: {{VALUE}}',
					'{{WRAPPER}} .service-box-layout1 .item-content p' => 'color: {{VALUE}}', 
					'{{WRAPPER}} .process-box-layout1 p' => 'color: {{VALUE}}', 
					'{{WRAPPER}} .practice-box-layout1 p' => 'color: {{VALUE}}', 
					'{{WRAPPER}} .process-box-layout2 .item-content p' => 'color: {{VALUE}}', 
					'{{WRAPPER}} .feature-box-layout2 p' => 'color: {{VALUE}}', 
					'{{WRAPPER}} .why-choose-box p' => 'color: {{VALUE}}', 
					'{{WRAPPER}} .single-practice-box3 p' => 'color: {{VALUE}}', 
				),
			),
			array(
				'name'     => 'sbox_desc_typo',
				'mode'     => 'group',
				'type'     => Group_Control_Typography::get_type(),
				'label'    => __( 'Typography', 'aeen-core' ),
				'selector' => '{{WRAPPER}} .feature-box-layout1 p, {{WRAPPER}} .service-box-layout1 .item-content p, {{WRAPPER}} .process-box-layout1 p, {{WRAPPER}} .practice-box-layout1 p, {{WRAPPER}} .process-box-layout2 .item-content p, {{WRAPPER}} .feature-box-layout2 p, {{WRAPPER}} .why-choose-box p, {{WRAPPER}} .single-practice-box3 p',
			),
			array(
				'mode' => 'section_end',
			),
		);
		return $fields;
	}

	protected function render() {
		$data = $this->get_settings();
		
		$this->rt_load_scripts();

		switch ( $data['box_style'] ) {
			case 'style8':
			$template = 'view-8';
			break;
			case 'style7':
			$template = 'view-7';
			break;
			case 'style6':
			$template = 'view-6';
			break;
			case 'style5':
			$template = 'view-5';
			break;
			case 'style4':
			$template = 'view-4';
			break;
			case 'style3':
			$template = 'view-3';
			break;
			case 'style2':
			$template = 'view-2';
			break;
			default:
			$template = 'view-1';
			break;
		}

		return $this->rt_template( $template, $data );
	}
}