<?php
/**
 * This file can be overridden by copying it to yourtheme/elementor-custom/title/class.php
 * 
 * @author  RadiusTheme
 * @since   1.0
 * @version 1.0
 */

namespace radiustheme\Aeen_Core;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Background;

if ( ! defined( 'ABSPATH' ) ) exit;

class Signature extends Custom_Widget_Base {

	public function __construct( $data = [], $args = null ){
		$this->rt_name = __( 'RT Signature', 'aeen-core' );
		$this->rt_base = 'rt-signature';
		parent::__construct( $data, $args );
	}

	public function rt_fields(){
		$fields = array(
			array(
				'id'      => 'sec_general',
				'mode'    => 'section_start',
				'label'   => __( 'General', 'aeen-core' ),
			),

			array(
				'id'    => 'signature_img',
				'type'    => Controls_Manager::MEDIA,
				'label'   => esc_html__( 'Image', 'aeen-core' ),
				'description' => esc_html__( 'Add Signature Image', 'aeen-core' ),
			),

			// Title
			array(
				'id'          => 'signature_title',
				'type'        => Controls_Manager::TEXT,
				'label'       => __( 'Name', 'aeen-core' ),
				'default'     => 'Michael Holmes',
				'label_block' => true,
			),
			array(
				'id'      => 'signature_designation',
				'type'    => Controls_Manager::TEXT,
				'label'   => __( 'Designation', 'aeen-core' ),
				'default' => 'Ceo, Ab Tact',
				'label_block' => true,
			),
			array(
				'id'      => 'align',
				'mode'    => 'responsive',
				'type'    => Controls_Manager::CHOOSE,
				'label'   => __( 'Alignment', 'aeen-core' ),
				'options' => $this->rt_alignment_options(),
				'default' => 'left',
				'selectors' => [
					'{{WRAPPER}} .about-info' => 'text-align: {{VALUE}};',
				],
			),

			array(
				'mode' => 'section_end',
			),

			// Style
			array(
				'id'      => 'signature_style',
				'mode'    => 'section_start',
				'tab'     => Controls_Manager::TAB_STYLE,
				'label'   => __( 'Style', 'aeen-core' ),
			),
			array(
				'id'      => 'name_heading',
				'type' => Controls_Manager::HEADING,
				'label'   => __( 'Name', 'aeen-core' ),
				'separator' => 'before',
			),
			array(
				'id'      => 'name_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Color', 'aeen-core' ),
				'selectors' => array( '{{WRAPPER}} .about-info .item-title' => 'color: {{VALUE}}' ),
			),
			array(
				'mode'     => 'group',
				'type'     => Group_Control_Typography::get_type(),
				'name'     => 'name_typo',
				'label'    => __( 'Typography', 'aeen-core' ),
				'selector' => '{{WRAPPER}} .about-info .item-title',
			),
			array(
				'id'      => 'designation_heading',
				'type' => Controls_Manager::HEADING,
				'label'   => __( 'Designation', 'aeen-core' ),
				'separator' => 'before',
			),
			array(
				'id'      => 'designation_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Color', 'aeen-core' ),
				'selectors' => array( '{{WRAPPER}} .about-info .item-sub-title' => 'color: {{VALUE}}' ),
			),
			array(
				'mode'     => 'group',
				'type'     => Group_Control_Typography::get_type(),
				'name'     => 'designation_typo',
				'label'    => __( 'Typography', 'aeen-core' ),
				'selector' => '{{WRAPPER}} .about-info .item-sub-title',
			),
			array(
				'mode' => 'section_end',
			),
		);
		return $fields;
	}

	protected function render() {
		$data = $this->get_settings();

		$template = 'view';

		return $this->rt_template( $template, $data );
	}
}