<?php
/**
 * This file can be overridden by copying it to yourtheme/elementor-custom/title/class.php
 * 
 * @author  RadiusTheme
 * @since   1.0
 * @version 1.0
 */

namespace radiustheme\Aeen_Core;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Background;

if ( ! defined( 'ABSPATH' ) ) exit;

class Skills extends Custom_Widget_Base {

	public function __construct( $data = [], $args = null ){
		$this->rt_name = __( 'RT Skills', 'aeen-core' );
		$this->rt_base = 'rt-skills';
		parent::__construct( $data, $args );
	}

	public function rt_fields(){

		$repeater = new \Elementor\Repeater();
		
		$repeater->add_control(
			'skill_title', [
				'type' 		  => Controls_Manager::TEXT,
				'label'       => esc_html__( 'Skill Name', 'salion-core' ),
				'default'     => esc_html__( 'Practice Area', 'salion-core' ),
				'label_block' => true,
			]
		);
		$repeater->add_control(
			'skill_number', [
				'type' 		  => Controls_Manager::TEXT,
				'label'       => esc_html__( 'Counter Number', 'salion-core' ),
				'default'     => esc_html__( '75', 'salion-core' ),
				'label_block' => true,
			]
		);
		$fields = array(
			array(
				'id'      => 'sec_rt_skills',
				'mode'    => 'section_start',
				'label'   => esc_html__( 'Skills', 'aeen-core' ),
			),
			array (
				'type'    => Controls_Manager::REPEATER,
				'id'      => 'skills',
				'label'   => esc_html__( 'Skills', 'aeen-core' ),
				'fields' => $repeater->get_controls(),
				'default' => [
					['skill_title' => __( 'Practice Area', 'aeen-core' ) ],	         
					['skill_title' => __( 'Happy Customer', 'aeen-core' ) ],	         
					['skill_title' => __( 'Firm Size', 'aeen-core' ) ],	         
					['skill_title' => __( 'Success Case', 'aeen-core' ) ],        
		       ],
			),
			array(
				'mode' => 'section_end',
			),
			
			// Style
			array(
				'id'      => 'pricing_table_style',
				'mode'    => 'section_start',
				'tab'     => Controls_Manager::TAB_STYLE,
				'label'   => __( 'Style', 'aeen-core' ),
			),
			array(
				'id'      => 'title_heading',
				'type' => Controls_Manager::HEADING,
				'label'   => __( 'Title Style', 'aeen-core' ),
				'separator' => 'before',
			),
			array(
				'id'      => 'title_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Color', 'aeen-core' ),
				'selectors' => array( '{{WRAPPER}} .about-box-layout8 .about-skill .progress .lead' => 'color: {{VALUE}}' ),
			),
			array(
				'mode'     => 'group',
				'type'     => Group_Control_Typography::get_type(),
				'name'     => 'title_typo',
				'label'    => __( 'Typography', 'aeen-core' ),
				'selector' => '{{WRAPPER}} .about-box-layout8 .about-skill .progress .lead',
			),
			array(
				'id'      => 'number_heading',
				'type' => Controls_Manager::HEADING,
				'label'   => __( 'Number Style', 'aeen-core' ),
				'separator' => 'before',
			),
			array(
				'id'      => 'number_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Color', 'aeen-core' ),
				'selectors' => array( '{{WRAPPER}} .about-box-layout7 .about-skill .progress-bar>span' => 'color: {{VALUE}}' ),
			),
			array(
				'mode'     => 'group',
				'type'     => Group_Control_Typography::get_type(),
				'name'     => 'number_typo',
				'label'    => __( 'Typography', 'aeen-core' ),
				'selector' => '{{WRAPPER}} .about-box-layout7 .about-skill .progress-bar>span',
			),
			array(
				'id'      => 'background_heading',
				'type' => Controls_Manager::HEADING,
				'label'   => __( 'Background Style', 'aeen-core' ),
				'separator' => 'before',
			),
			array(
				'id'        => 'bar_bg',
				'type'      => Controls_Manager::COLOR,
				'label'     => __( 'Background color', 'aeen-core' ),
				'default'   => '',
				'selectors' => array( 
					'{{WRAPPER}} .about-box-layout8 .about-skill .progress' => 'background-color: {{VALUE}}', 
				),
			),
			array(
				'id'        => 'progress_bg',
				'type'      => Controls_Manager::COLOR,
				'label'     => __( 'Progress color', 'aeen-core' ),
				'default'   => '',
				'selectors' => array( 
					'{{WRAPPER}} .about-box-layout7 .about-skill .progress-bar' => 'background-color: {{VALUE}}', 
				),
			),
			array(
				'mode' => 'section_end',
			),
		);
		return $fields;
	}

	protected function render() {
		$data = $this->get_settings();

		$template = 'view';

		return $this->rt_template( $template, $data );
	}
}